@@ -1,6 +1,6 @@
 /* gcompris - py-mod-gcompris.c
  *
- * Copyright (C) 2003 Olivier Samyn <osamyn@ulb.ac.be>
+ * Copyright (C) 2003, 2008 Olivier Samyn <osamyn@ulb.ac.be>
  *
  *   This program is free software; you can redistribute it and/or modify
  *   it under the terms of the GNU General Public License as published by
@@ -42,7 +42,7 @@ typedef int Py_ssize_t;
 #include "py-mod-anim.h"
 #include "py-mod-admin.h"
 
-void initgnomecanvas (void);
+void initgoocanvas (void);
 
 void pair_in_dict(gpointer key,
 		  gpointer value,
@@ -109,17 +109,17 @@ py_gc_board_end(PyObject* self, PyObject* args)
 }
 
 
-/* void	gc_bar_start (GnomeCanvas *theCanvas); */
+/* void	gc_bar_start (GooCanvas *theCanvas); */
 static PyObject*
 py_gc_bar_start(PyObject* self, PyObject* args)
 {
   PyObject* pyCanvas;
-  GnomeCanvas* canvas;
+  GooCanvas* canvas;
 
   /* Parse arguments */
   if(!PyArg_ParseTuple(args, "O:gc_bar_start", &pyCanvas))
     return NULL;
-  canvas = (GnomeCanvas*) pygobject_get(pyCanvas);
+  canvas = (GooCanvas*) pygobject_get(pyCanvas);
 
   /* Call the corresponding C function */
   gc_bar_start(canvas);
@@ -130,27 +130,68 @@ py_gc_bar_start(PyObject* self, PyObject* args)
 }
 
 
-/* GnomeCanvasItem *gc_set_background(GnomeCanvasGroup *parent, gchar *file); */
+/* GooCanvasItem *gc_set_background(GooCanvasGroup *parent, gchar *file); */
 static PyObject*
 py_gc_set_background(PyObject* self, PyObject* args)
 {
   PyObject* pyCanvasGroup;
-  GnomeCanvasGroup* canvasGroup;
+  GooCanvasItem* canvasGroup;
   gchar* file;
-  PyObject* pyResult;
-  GnomeCanvasItem* result;
 
   /* Parse arguments */
   if(!PyArg_ParseTuple(args, "Os:gc_set_background", &pyCanvasGroup, &file))
     return NULL;
-  canvasGroup = (GnomeCanvasGroup*) pygobject_get(pyCanvasGroup);
+  canvasGroup = (GooCanvasItem*) pygobject_get(pyCanvasGroup);
 
   /* Call the corresponding C function */
-  result = gc_set_background(canvasGroup, file);
+  gc_set_background(canvasGroup, file);
 
-  /* Create and return the result */
-  pyResult = pygobject_new((GObject*)result);
-  return pyResult;
+  return Py_None;
+}
+
+
+/* GooCanvasItem *gc_set_background_by_id(GooCanvasGroup *parent,
+   RsvgHandle svg_handle, gchar *id); */
+static PyObject*
+py_gc_set_background_by_id(PyObject* self, PyObject* args)
+{
+  PyObject* pyCanvasGroup;
+  PyObject* pySvgHandle;
+  GooCanvasItem* canvasGroup;
+  RsvgHandle *svg_handle;
+  gchar* id;
+
+  /* Parse arguments */
+  if(!PyArg_ParseTuple(args, "OOs:gc_set_background_by_id",
+		       &pyCanvasGroup, &pySvgHandle, &id))
+    return NULL;
+  canvasGroup = (GooCanvasItem*) pygobject_get(pyCanvasGroup);
+  svg_handle = (RsvgHandle*) pygobject_get(pySvgHandle);
+
+  /* Call the corresponding C function */
+  gc_set_background_by_id(canvasGroup, svg_handle, id);
+
+  return Py_None;
+}
+
+
+/* GooCanvasItem *gc_set_default_background(GooCanvasGroup *parent) */
+static PyObject*
+py_gc_set_default_background(PyObject* self, PyObject* args)
+{
+  PyObject* pyCanvasGroup;
+  GooCanvasItem* canvasGroup;
+
+  /* Parse arguments */
+  if(!PyArg_ParseTuple(args, "O:gc_set_background_by_id",
+		       &pyCanvasGroup))
+    return NULL;
+  canvasGroup = (GooCanvasItem*) pygobject_get(pyCanvasGroup);
+
+  /* Call the corresponding C function */
+  gc_set_default_background(canvasGroup);
+
+  return Py_None;
 }
 
 
@@ -177,20 +218,20 @@ py_gc_bar_set_level(PyObject* self, PyObject* args)
 }
 
 
-/* void gc_bar_set_repeat_icon (GdkPixbuf *pixmap); */
+/* void gc_bar_set_repeat_icon (RsvgHandle *svg_handle); */
 static PyObject*
 py_gc_bar_set_repeat_icon(PyObject* self, PyObject* args)
 {
   PyObject* pyObject;
-  GdkPixbuf* pixmap;
+  RsvgHandle *svg_handle;
 
   /* Parse arguments */
   if(!PyArg_ParseTuple(args, "O:gc_bar_set_repeat_icon", &pyObject))
     return NULL;
-  pixmap = (GdkPixbuf*) pygobject_get(pyObject);
+  svg_handle = (RsvgHandle*) pygobject_get(pyObject);
 
   /* Call the corresponding C function */
-  gc_bar_set_repeat_icon(pixmap);
+  gc_bar_set_repeat_icon(svg_handle);
 
   /* Create and return the result */
   Py_INCREF(Py_None);
@@ -235,11 +276,32 @@ py_gc_bar_hide(PyObject* self, PyObject* args)
   return Py_None;
 }
 
-/* GnomeCanvas *gc_get_canvas(void); */
+/* void gc_bar_location (int x, int y, double zoom); */
+static PyObject*
+py_gc_bar_location(PyObject* self, PyObject* args)
+{
+  gint x;
+  gint y;
+  double zoom;
+
+  /* Parse arguments */
+  if(!PyArg_ParseTuple(args, "iid:gc_bar_location",
+                       &x, &y, &zoom))
+    return NULL;
+
+  /* Call the corresponding C function */
+  gc_bar_location(x, y, zoom);
+
+  /* Create and return the result */
+  Py_INCREF(Py_None);
+  return Py_None;
+}
+
+/* GooCanvas *gc_get_canvas(void); */
 static PyObject*
 py_gc_get_canvas(PyObject* self, PyObject* args)
 {
-  GnomeCanvas* result;
+  GooCanvas* result;
   /* Parse arguments */
   if(!PyArg_ParseTuple(args, ":gc_get_canvas"))
     return NULL;
@@ -342,14 +404,15 @@ py_gc_cursor_set(PyObject* self, PyObject* args)
 /* Some functions and variables needed to get the image selector working */
 static PyObject* pyImageSelectorCallBackFunc = NULL;
 
-void pyImageSelectorCallBack(gchar* image){
+void pyImageSelectorCallBack(gchar* image, void *user_data){
   PyObject* args;
   PyObject* result;
   if(pyImageSelectorCallBackFunc==NULL) return;
 
   /* Build arguments */
-  args = PyTuple_New(1);
+  args = PyTuple_New(2);
   PyTuple_SetItem(args, 0, Py_BuildValue("s", image));
+  PyTuple_SetItem(args, 1, Py_BuildValue("O", user_data));
   result = PyObject_CallObject(pyImageSelectorCallBackFunc, args);
   if(result==NULL){
     PyErr_Print();
@@ -369,13 +432,15 @@ py_gc_selector_images_start(PyObject* self, PyObject* args)
   GcomprisBoard* cGcomprisBoard;
   PyObject* pyCallback;
   gchar* dataset;
+  void *user_data;
 
   /* Parse arguments */
   if(!PyArg_ParseTuple(args,
-		       "OsO:gc_selector_images_start",
+		       "OsOO:gc_selector_images_start",
 		       &pyGcomprisBoard,
 		       &dataset,
-		       &pyCallback))
+		       &pyCallback,
+		       &user_data))
     return NULL;
   if(!PyCallable_Check(pyCallback)) return NULL;
   cGcomprisBoard = ((pyGcomprisBoardObject*) pyGcomprisBoard)->cdata;
@@ -383,8 +448,9 @@ py_gc_selector_images_start(PyObject* self, PyObject* args)
   /* Call the corresponding C function */
   pyImageSelectorCallBackFunc = pyCallback;
   gc_selector_images_start(cGcomprisBoard,
-				 dataset,
-				 pyImageSelectorCallBack);
+			   dataset,
+			   pyImageSelectorCallBack,
+			   user_data);
 
   /* Create and return the result */
   Py_INCREF(Py_None);
@@ -466,15 +532,16 @@ py_gc_selector_images_stop(PyObject* self, PyObject* args)
 /* Some functions and variables needed to get the file selector working */
 static PyObject* pyFileSelectorCallBackFunc = NULL;
 
-void pyFileSelectorCallBack(gchar* file, char* file_type){
+void pyFileSelectorCallBack(gchar* file, char* file_type, void *user_context){
   PyObject* args;
   PyObject* result;
   if(pyFileSelectorCallBackFunc==NULL) return;
 
   /* Build arguments */
-  args  = PyTuple_New(2);
+  args  = PyTuple_New(3);
   PyTuple_SetItem(args, 0, Py_BuildValue("s", file));
   PyTuple_SetItem(args, 1, Py_BuildValue("s", file_type));
+  PyTuple_SetItem(args, 2, Py_BuildValue("O", user_context));
   result = PyObject_CallObject(pyFileSelectorCallBackFunc, args);
   if(result==NULL){
     PyErr_Print();
@@ -488,7 +555,8 @@ void pyFileSelectorCallBack(gchar* file, char* file_type){
 /* void gc_selector_file_load(GcomprisBoard *gcomprisBoard,
                                     gchar *rootdir,
 				    gchar *file_types, (A Comma separated text explaining the different file types)
-                                    FileSelectorCallBack fscb);
+                                    FileSelectorCallBack fscb,
+				    void *pyUserContext);
 */
 static PyObject*
 py_gc_selector_file_load(PyObject* self, PyObject* args){
@@ -497,14 +565,16 @@ py_gc_selector_file_load(PyObject* self, PyObject* args){
   PyObject* pyCallback;
   gchar* rootdir;
   gchar* file_types;
+  void *pyUserContext;
 
   /* Parse arguments */
   if(!PyArg_ParseTuple(args,
-		       "OssO:gc_selector_file_load",
+		       "OssOO:gc_selector_file_load",
 		       &pyGcomprisBoard,
 		       &rootdir,
 		       &file_types,
-		       &pyCallback))
+		       &pyCallback,
+		       &pyUserContext))
     return NULL;
   if(!PyCallable_Check(pyCallback)) return NULL;
   cGcomprisBoard = ((pyGcomprisBoardObject*) pyGcomprisBoard)->cdata;
@@ -512,9 +582,10 @@ py_gc_selector_file_load(PyObject* self, PyObject* args){
   /* Call the corresponding C function */
   pyFileSelectorCallBackFunc = pyCallback;
   gc_selector_file_load(cGcomprisBoard,
-                              rootdir,
-			      file_types,
-                              pyFileSelectorCallBack);
+			rootdir,
+			file_types,
+			pyFileSelectorCallBack,
+			pyUserContext);
 
   /* Create and return the result */
   Py_INCREF(Py_None);
@@ -523,9 +594,10 @@ py_gc_selector_file_load(PyObject* self, PyObject* args){
 
 
 /* void gc_selector_file_save(GcomprisBoard *gcomprisBoard,
-                                    gchar *rootdir,
-				    gchar *file_types, (A Comma separated text explaining the different file types)
-                                    FileSelectorCallBack fscb);
+                              gchar *rootdir,
+			      gchar *file_types, (A Comma separated text explaining the different file types)
+                              FileSelectorCallBack fscb,
+			      void *user_context);
 */
 static PyObject*
 py_gc_selector_file_save(PyObject* self, PyObject* args){
@@ -534,14 +606,16 @@ py_gc_selector_file_save(PyObject* self, PyObject* args){
   PyObject* pyCallback;
   gchar* rootdir;
   char* file_types;
+  void *pyUserContext;
 
   /* Parse arguments */
   if(!PyArg_ParseTuple(args,
-		       "OssO:gc_selector_file_save",
+		       "OssOO:gc_selector_file_save",
 		       &pyGcomprisBoard,
 		       &rootdir,
 		       &file_types,
-		       &pyCallback))
+		       &pyCallback,
+		       &pyUserContext))
     return NULL;
   if(!PyCallable_Check(pyCallback)) return NULL;
   cGcomprisBoard = ((pyGcomprisBoardObject*) pyGcomprisBoard)->cdata;
@@ -549,9 +623,10 @@ py_gc_selector_file_save(PyObject* self, PyObject* args){
   /* Call the corresponding C function */
   pyFileSelectorCallBackFunc = pyCallback;
   gc_selector_file_save(cGcomprisBoard,
-                              rootdir,
-			      file_types,
-                              pyFileSelectorCallBack);
+			rootdir,
+			file_types,
+			pyFileSelectorCallBack,
+			pyUserContext);
 
   /* Create and return the result */
   Py_INCREF(Py_None);
@@ -1520,10 +1595,13 @@ static PyMethodDef PythonGcomprisModule[] = {
   { "end_board",  py_gc_board_end, METH_VARARGS, "gc_board_end" },
   { "bar_start",  py_gc_bar_start, METH_VARARGS, "gc_bar_start" },
   { "set_background",  py_gc_set_background, METH_VARARGS, "gc_set_background" },
+  { "set_background_by_id",  py_gc_set_background_by_id, METH_VARARGS, "gc_set_background_by_id" },
+  { "set_default_background",  py_gc_set_default_background, METH_VARARGS, "gc_set_default_background" },
   { "bar_set_level",  py_gc_bar_set_level, METH_VARARGS, "gc_bar_set_level" },
   { "bar_set_repeat_icon",  py_gc_bar_set_repeat_icon, METH_VARARGS, "gc_bar_set_repeat_icon" },
   { "bar_set",  py_gc_bar_set, METH_VARARGS, "gc_bar_set" },
   { "bar_hide",  py_gc_bar_hide, METH_VARARGS, "gc_bar_hide" },
+  { "bar_location",  py_gc_bar_location, METH_VARARGS, "gc_bar_location" },
   { "get_canvas",  py_gc_get_canvas, METH_VARARGS, "gc_get_canvas" },
   { "get_window",  py_gc_get_window, METH_VARARGS, "gc_get_window" },
   { "get_locale",  py_gc_locale_get, METH_VARARGS, "gc_locale_get" },
@@ -1585,7 +1663,6 @@ void python_gcompris_module_init(void)
 
   /* The GComprisBarFlags enum constants */
   PyModule_AddIntConstant(gcomprisModule, "BAR_LEVEL",       GC_BAR_LEVEL);
-  PyModule_AddIntConstant(gcomprisModule, "BAR_OK",          GC_BAR_OK);
   PyModule_AddIntConstant(gcomprisModule, "BAR_REPEAT",      GC_BAR_REPEAT);
   PyModule_AddIntConstant(gcomprisModule, "BAR_REPEAT_ICON", GC_BAR_REPEAT_ICON);
   PyModule_AddIntConstant(gcomprisModule, "BAR_CONFIG",      GC_BAR_CONFIG);
@@ -1640,7 +1717,7 @@ void python_gcompris_module_init(void)
 
 
   /* Initialize the sub modules */
-  initgnomecanvas();
+  initgoocanvas();
   python_gcompris_bonus_module_init();
   python_gc_score_module_init();
   python_gc_skin_module_init();
