@@ -1,3 +1,20 @@
+/* gcompris - py-mod-utils.c
+ *
+ * Copyright (C) 2003, 2008 Olivier Samyn <osamyn@ulb.ac.be>
+ *
+ *   This program is free software; you can redistribute it and/or modify
+ *   it under the terms of the GNU General Public License as published by
+ *   the Free Software Foundation; either version 3 of the License, or
+ *   (at your option) any later version.
+ *
+ *   This program is distributed in the hope that it will be useful,
+ *   but WITHOUT ANY WARRANTY; without even the implied warranty of
+ *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ *   GNU General Public License for more details.
+ *
+ *   You should have received a copy of the GNU General Public License
+ *   along with this program; if not, see <http://www.gnu.org/licenses/>.
+ */
 #include <Python.h>
 #define NO_IMPORT_PYGOBJECT 1
 #include <pygobject.h>
@@ -36,6 +53,31 @@ py_gc_pixmap_load(PyObject* self, PyObject* args)
 
 }
 
+/* RsvgHandle *gc_svg_load(char *pixmapfile); */
+static PyObject*
+py_gc_svg_load(PyObject* self, PyObject* args)
+{
+  char* pixmapfile;
+  RsvgHandle* result;
+  PyObject* pyresult;
+
+  /* Parse arguments */
+
+  if(!PyArg_ParseTuple(args, "s:gc_svg_load", &pixmapfile))
+    return NULL;
+
+  /* Call the corresponding C function */
+  result = gc_rsvg_load(pixmapfile);
+
+  /* Create and return the result */
+  pyresult = (PyObject*) pygobject_new((GObject*) result);
+
+  rsvg_handle_free(result);
+
+  return(pyresult);
+
+}
+
 /* gchar *gc_file_find_absolute(gchar *file); */
 static PyObject*
 py_gc_file_find_absolute(PyObject* self, PyObject* args)
@@ -55,26 +97,28 @@ py_gc_file_find_absolute(PyObject* self, PyObject* args)
 }
 
 
-
-/* void	gc_item_focus_set(GnomeCanvasItem *item, gboolean focus); */
+/* gint	gc_item_focus_init(GooCanvasItem *source_item,
+                           GooCanvasItem *target_item);
+*/
 static PyObject*
-py_gc_item_focus_set(PyObject* self, PyObject* args)
+py_gc_item_focus_init(PyObject* self, PyObject* args)
 {
   PyObject* pyitem;
-  GnomeCanvasItem* item;
-  gint pyfocus;
-  gboolean focus;
+  PyObject* pytarget;
+  GooCanvasItem* item;
+  GooCanvasItem* target = NULL;
 
   /* Parse arguments */
-  if(!PyArg_ParseTuple(args, "Oi:gc_item_focus_set", &pyitem, &pyfocus))
+  if(!PyArg_ParseTuple(args, "OO:gc_item_focus_init",
+		       &pyitem, &pytarget))
     return NULL;
 
-  item = (GnomeCanvasItem*) pygobject_get(pyitem);
-  if(pyfocus>0) focus = TRUE;
-  else focus = FALSE;
+  item = (GooCanvasItem*) pygobject_get(pyitem);
+  if(pytarget != Py_None)
+    target = (GooCanvasItem*) pygobject_get(pytarget);
 
   /* Call the corresponding C function */
-  gc_item_focus_set(item, focus);
+  gc_item_focus_init(item, target);
 
   /* Create and return the result */
   Py_INCREF(Py_None);
@@ -82,45 +126,47 @@ py_gc_item_focus_set(PyObject* self, PyObject* args)
 }
 
 
-/* gint	gc_item_focus_event(GnomeCanvasItem *item,
-                                  GdkEvent *event,
-                                  GnomeCanvasItem *dest_item);
+/* gint	gc_item_focus_remove(GooCanvasItem *source_item,
+                           GooCanvasItem *target_item);
 */
 static PyObject*
-py_gc_item_focus_event(PyObject* self, PyObject* args)
+py_gc_item_focus_remove(PyObject* self, PyObject* args)
 {
   PyObject* pyitem;
-  GnomeCanvasItem* item;
-  PyObject* pyevent;
-  GdkEvent* event;
-  gint result;
+  PyObject* pytarget;
+  GooCanvasItem* item;
+  GooCanvasItem* target = NULL;
 
   /* Parse arguments */
-  if(!PyArg_ParseTuple(args, "OO:gc_item_focus_event", &pyitem, &pyevent))
+  if(!PyArg_ParseTuple(args, "OO:gc_item_focus_remove",
+		       &pyitem, &pytarget))
     return NULL;
-  item = (GnomeCanvasItem*) pygobject_get(pyitem);
-  event = (GdkEvent*) pygobject_get(pyevent);
+
+  item = (GooCanvasItem*) pygobject_get(pyitem);
+  if(pytarget != Py_None)
+    target = (GooCanvasItem*) pygobject_get(pytarget);
 
   /* Call the corresponding C function */
-  result = gc_item_focus_event(item, event, NULL);
+  gc_item_focus_remove(item, target);
 
   /* Create and return the result */
-  return Py_BuildValue("i", result);
+  Py_INCREF(Py_None);
+  return Py_None;
 }
 
 
-/* void gc_item_absolute_move(GnomeCanvasItem *item, int x, int y); */
+/* void gc_item_absolute_move(GooCanvasItem *item, int x, int y); */
 static PyObject*
 py_gc_item_absolute_move(PyObject* self, PyObject* args)
 {
   PyObject* pyitem;
-  GnomeCanvasItem* item;
+  GooCanvasItem* item;
   int x, y;
 
   /* Parse arguments */
   if(!PyArg_ParseTuple(args, "Oii:gc_item_absolute_move", &pyitem, &x, &y))
     return NULL;
-  item = (GnomeCanvasItem*) pygobject_get(pyitem);
+  item = (GooCanvasItem*) pygobject_get(pyitem);
 
   /* Call the corresponding C function */
   gc_item_absolute_move(item, x, y);
@@ -131,18 +177,18 @@ py_gc_item_absolute_move(PyObject* self, PyObject* args)
 }
 
 
-/* void gc_item_rotate(GnomeCanvasItem *item, double angle); */
+/* void gc_item_rotate(GooCanvasItem *item, double angle); */
 static PyObject*
 py_gc_item_rotate(PyObject* self, PyObject* args)
 {
   PyObject* pyitem;
-  GnomeCanvasItem* item;
+  GooCanvasItem* item;
   double angle;
 
   /* Parse arguments */
   if(!PyArg_ParseTuple(args, "Od:gc_item_rotate_relative", &pyitem, &angle))
     return NULL;
-  item = (GnomeCanvasItem*) pygobject_get(pyitem);
+  item = (GooCanvasItem*) pygobject_get(pyitem);
 
   /* Call the corresponding C function */
   gc_item_rotate(item, angle);
@@ -153,18 +199,18 @@ py_gc_item_rotate(PyObject* self, PyObject* args)
 }
 
 
-/* void gc_item_rotate_relative(GnomeCanvasItem *item, double angle); */
+/* void gc_item_rotate_relative(GooCanvasItem *item, double angle); */
 static PyObject*
 py_gc_item_rotate_relative(PyObject* self, PyObject* args)
 {
   PyObject* pyitem;
-  GnomeCanvasItem* item;
+  GooCanvasItem* item;
   double angle;
 
   /* Parse arguments */
   if(!PyArg_ParseTuple(args, "Od:gc_item_rotate_relative", &pyitem, &angle))
     return NULL;
-  item = (GnomeCanvasItem*) pygobject_get(pyitem);
+  item = (GooCanvasItem*) pygobject_get(pyitem);
 
   /* Call the corresponding C function */
   gc_item_rotate_relative(item, angle);
@@ -175,19 +221,19 @@ py_gc_item_rotate_relative(PyObject* self, PyObject* args)
 }
 
 
-/* void gc_item_rotate_with_center(GnomeCanvasItem *item, double angle, int x, int y); */
+/* void gc_item_rotate_with_center(GooCanvasItem *item, double angle, int x, int y); */
 static PyObject*
 py_gc_item_rotate_with_center(PyObject* self, PyObject* args)
 {
   PyObject* pyitem;
-  GnomeCanvasItem* item;
+  GooCanvasItem* item;
   double angle;
   int x,y;
 
   /* Parse arguments */
   if(!PyArg_ParseTuple(args, "Odii:gc_item_rotate_with_center", &pyitem, &angle, &x, &y))
     return NULL;
-  item = (GnomeCanvasItem*) pygobject_get(pyitem);
+  item = (GooCanvasItem*) pygobject_get(pyitem);
 
   /* Call the corresponding C function */
   gc_item_rotate_with_center(item, angle, x, y);
@@ -198,19 +244,19 @@ py_gc_item_rotate_with_center(PyObject* self, PyObject* args)
 }
 
 
-/* void gc_item_rotate_relative_with_center(GnomeCanvasItem *item, double angle, int x, int y); */
+/* void gc_item_rotate_relative_with_center(GooCanvasItem *item, double angle, int x, int y); */
 static PyObject*
 py_gc_item_rotate_relative_with_center(PyObject* self, PyObject* args)
 {
   PyObject* pyitem;
-  GnomeCanvasItem* item;
+  GooCanvasItem* item;
   double angle;
   int x,y;
 
   /* Parse arguments */
   if(!PyArg_ParseTuple(args, "Odii:gc_item_rotate_relative_with_center", &pyitem, &angle, &x, &y))
     return NULL;
-  item = (GnomeCanvasItem*) pygobject_get(pyitem);
+  item = (GooCanvasItem*) pygobject_get(pyitem);
 
   /* Call the corresponding C function */
   gc_item_rotate_relative_with_center(item, angle, x, y);
@@ -285,7 +331,7 @@ static PyObject*
 py_gcompris_filename_pass(PyObject* self, PyObject* args)
 {
   PyObject* pyitem;
-  GnomeCanvasItem *item;
+  GooCanvasItem *item;
   char *string;
 
 
@@ -294,7 +340,7 @@ py_gcompris_filename_pass(PyObject* self, PyObject* args)
     return NULL;
 
   /* pass parameter from python */
-  item = (GnomeCanvasItem *) pygobject_get(pyitem);
+  item = (GooCanvasItem *) pygobject_get(pyitem);
 
   /* gcompris_filename_pass( item, string); */
   g_object_set_data( G_OBJECT(item), "filename", string);
@@ -309,22 +355,23 @@ py_gcompris_filename_pass(PyObject* self, PyObject* args)
  * Set a property in a canvas object
  * ---------------------------------
  */
-/* void canvas_set_property(GnomeCanvasItem *item, gchar *property, gchar* value) */
+/* void canvas_set_property(GooCanvasItem *item, gchar *property, gchar* value) */
 static PyObject*
 py_gcompris_canvas_set_property(PyObject* self, PyObject* args)
 {
   PyObject* pyitem;
-  GnomeCanvasItem *item;
+  GooCanvasItem *item;
   char *property;
   char *value;
 
 
   /* Parse arguments */
-  if(!PyArg_ParseTuple(args, "Oss:gcompris_canvas_set_property", &pyitem, &property, &value))
+  if(!PyArg_ParseTuple(args, "Oss:gcompris_canvas_set_property",
+		       &pyitem, &property, &value))
     return NULL;
 
   /* pass parameter from python */
-  item = (GnomeCanvasItem *) pygobject_get(pyitem);
+  item = (GooCanvasItem *) pygobject_get(pyitem);
 
   /* gcompris_filename_pass( item, string); */
   g_object_set_data( G_OBJECT(item), property, value);
@@ -339,12 +386,12 @@ py_gcompris_canvas_set_property(PyObject* self, PyObject* args)
  * Get a property in a canvas object
  * ---------------------------------
  */
-/* gchar *canvas_get_property(GnomeCanvasItem *item, gchar *property) */
+/* gchar *canvas_get_property(GooCanvasItem *item, gchar *property) */
 static PyObject*
 py_gcompris_canvas_get_property(PyObject* self, PyObject* args)
 {
   PyObject* pyitem;
-  GnomeCanvasItem *item;
+  GooCanvasItem *item;
   char  *property;
   gchar *result;
 
@@ -353,7 +400,7 @@ py_gcompris_canvas_get_property(PyObject* self, PyObject* args)
     return NULL;
 
   /* pass parameter from python */
-  item = (GnomeCanvasItem *) pygobject_get(pyitem);
+  item = (GooCanvasItem *) pygobject_get(pyitem);
 
   /* gcompris_filename_pass( item, string); */
   result = g_object_get_data( G_OBJECT(item), property);
@@ -371,9 +418,10 @@ py_gcompris_canvas_get_property(PyObject* self, PyObject* args)
 
 static PyMethodDef PythonGcomprisUtilsModule[] = {
   { "load_pixmap",  py_gc_pixmap_load, METH_VARARGS, "gc_pixmap_load" },
+  { "load_svg",  py_gc_svg_load, METH_VARARGS, "gc_rsvg_load" },
   { "find_file_absolute",  py_gc_file_find_absolute, METH_VARARGS, "gc_file_find_absolute" },
-  { "set_image_focus",  py_gc_item_focus_set, METH_VARARGS, "gc_item_focus_set" },
-  { "item_event_focus",  py_gc_item_focus_event, METH_VARARGS, "gc_item_focus_event" },
+  { "item_focus_init",  py_gc_item_focus_init, METH_VARARGS, "gc_item_focus_init" },
+  { "item_focus_remove",  py_gc_item_focus_remove, METH_VARARGS, "gc_item_focus_remove" },
   { "item_absolute_move",  py_gc_item_absolute_move, METH_VARARGS, "gc_item_absolute_move" },
   { "item_rotate",  py_gc_item_rotate, METH_VARARGS, "gc_item_rotate" },
   { "item_rotate_relative",  py_gc_item_rotate_relative, METH_VARARGS, "gc_item_rotate_relative" },
