@@ -1,6 +1,6 @@
 /* gcompris - python.c
  *
- * Copyright (C) 2003 GCompris Developpement Team
+ * Copyright (C) 2003, 2008 GCompris Developpement Team
  *
  *   This program is free software; you can redistribute it and/or modify
  *   it under the terms of the GNU General Public License as published by
@@ -17,8 +17,9 @@
  */
 
 #include <Python.h>
-#define NO_IMPORT_PYGOBJECT 1
+//#define NO_IMPORT_PYGOBJECT 1
 #include <pygobject.h>
+#include <pygtk/pygtk.h>
 #include "gcompris/gcompris.h"
 #include "py-gcompris-board.h"
 #include "py-mod-gcompris.h"
@@ -84,7 +85,7 @@ static BoardPlugin menu_bp_no_config =
     NULL,
     NULL,
     N_("Python Board"),
-    N_("Special board that embeds python into GCompris."),
+    N_("Special board that embeds python into gcompris."),
     "Olivier Samyn <osamyn@ulb.ac.be>",
     pythonboard_init,
     NULL,
@@ -143,7 +144,6 @@ pythonboard_init (GcomprisBoard *agcomprisBoard){
 
   char* board_file_name;
   char* boardclass;
-  gchar *boarddir;
   PyObject* module_dict;
   PyObject* py_boardclass;
 
@@ -179,7 +179,7 @@ pythonboard_init (GcomprisBoard *agcomprisBoard){
     execstr = g_strdup_printf("import sys; sys.path.append('%s')",properties->package_python_plugin_dir );
 #endif
 
-    g_warning("Executing %s\n", execstr);
+    g_message("Executing %s\n", execstr);
     if(PyRun_SimpleString(execstr)!=0){
       pythonboard_is_ready = FALSE;
       g_warning("! Python disabled: Cannot add plugins dir into search path\n");
@@ -219,20 +219,13 @@ pythonboard_init (GcomprisBoard *agcomprisBoard){
 	    board_file_name = strchr(board->type, ':')+1;
 	    boardclass = g_strdup_printf("Gcompris_%s", board_file_name);
 
-	    /* Test if board come with -L option */
+	    /* Test if board come with --python_plugin_dir option */
 
-	    g_warning("board_dir: '%s' package_data_dir '%s' file_name '%s'",
+	    g_message("board_dir: '%s' python_plugin_dir '%s' file_name '%s'",
 		      board->board_dir,
 		      properties->package_python_plugin_dir,
 		      board_file_name);
 
-	    if (strcmp(board->board_dir, properties->package_python_plugin_dir)!=0){
-	      boarddir = g_strdup_printf("sys.path.append('%s/')", board->board_dir);
-
-	      PyRun_SimpleString(boarddir);
-	      g_free(boarddir);
-	    }
-
 	    /* Insert the board module into the python's interpreter */
 	    python_board_module = PyImport_ImportModuleEx(board_file_name,
 							  globals,
@@ -248,7 +241,7 @@ pythonboard_init (GcomprisBoard *agcomprisBoard){
 
 	      if (PyObject_HasAttrString( py_boardclass, "config_start")) {
 		config_boards = g_list_append(config_boards, board);
-		g_warning("The board '%s' has a configuration entry",
+		g_message("The board '%s' has a configuration entry",
 			  board_file_name);
 	      }
 	    }
@@ -536,7 +529,8 @@ static void pythonboard_repeat (void){
  */
 
 /*
- * Normally python in already runningwhen config_start is called. If not config_stop has to stop it.
+ * Normally python in already running when config_start is called.
+ * If not config_stop has to stop it.
  */
 
 static gboolean python_run_by_config = FALSE;
