@@ -1,20 +1,20 @@
-/*  GCompris -- This files comes from XMMS
+/*  GCompris -- board.c : Originaly this files comes from XMMS
  *
- *  XMMS - Cross-platform multimedia player
  *  Copyright (C) 1998-2000  Peter Alm, Mikael Alm, Olle Hallnas, Thomas Nilsson and 4Front Technologies
+ *  Copyright (C) 2008 Bruno Coudoin
  *
- *  This program is free software; you can redistribute it and/or modify
- *  it under the terms of the GNU General Public License as published by
- *  the Free Software Foundation; either version 3 of the License, or
- *  (at your option) any later version.
+ *   This program is free software; you can redistribute it and/or modify
+ *   it under the terms of the GNU General Public License as published by
+ *   the Free Software Foundation; either version 3 of the License, or
+ *   (at your option) any later version.
  *
- *  This program is distributed in the hope that it will be useful,
- *  but WITHOUT ANY WARRANTY; without even the implied warranty of
- *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- *  GNU General Public License for more details.
+ *   This program is distributed in the hope that it will be useful,
+ *   but WITHOUT ANY WARRANTY; without even the implied warranty of
+ *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ *   GNU General Public License for more details.
  *
- *  You should have received a copy of the GNU General Public License
- *  along with this program; if not, see <http://www.gnu.org/licenses/>.
+ *   You should have received a copy of the GNU General Public License
+ *   along with this program; if not, see <http://www.gnu.org/licenses/>.
  */
 
 #include <string.h>
@@ -28,7 +28,7 @@ static struct BoardPluginData *bp_data;
 static gboolean	 get_board_playing(void);
 
 #ifdef STATIC_MODULE
-gint gc_activation_check(char *code);
+int gc_activation_check(char *code);
 extern BoardPlugin * get_advanced_colors_bplugin_info();
 extern BoardPlugin * get_algebra_bplugin_info();
 extern BoardPlugin * get_algebra_guesscount_bplugin_info();
@@ -220,7 +220,7 @@ gc_board_check_file(GcomprisBoard *gcomprisBoard)
   GcomprisProperties	*properties = gc_prop_get();
   BoardPlugin *bp;
   guint        i=0;
-  gint         key_is_valid = 0;
+  guint        key_is_valid = 0;
 
   g_assert(gcomprisBoard!=NULL);
   g_assert(properties->key!=NULL);
@@ -236,7 +236,7 @@ gc_board_check_file(GcomprisBoard *gcomprisBoard)
     key_is_valid = gc_activation_check(properties->key);
 
   i = 0;
-  if(key_is_valid >= 1)
+  if(key_is_valid == 1)
     {
       while(static_boards[i++] != NULL) {
 
@@ -245,7 +245,7 @@ gc_board_check_file(GcomprisBoard *gcomprisBoard)
 
 	if(bp->is_our_board(gcomprisBoard)) {
 	  /* Great, we found our plugin */
-	  g_warning("We found the correct plugin for board %s (type=%s)\n",
+	  g_message("We found the correct plugin for board %s (type=%s)\n",
 		    gcomprisBoard->name, gcomprisBoard->type);
 
 	  gcomprisBoard->plugin = bp;
@@ -321,7 +321,7 @@ gc_board_check_file(GcomprisBoard *gcomprisBoard)
 
   gmodule = g_module_open (gmodule_file, 0);
   if(gmodule) {
-    g_warning("opened module %s with name %s\n", gmodule_file, type);
+    g_message("opened module %s with name %s\n", gmodule_file, type);
   } else {
     g_warning("Failed to open module %s with name %s (error=%s)\n", gmodule_file,
 	      type, g_module_error());
@@ -346,7 +346,7 @@ gc_board_check_file(GcomprisBoard *gcomprisBoard)
 
       if(bp->is_our_board(gcomprisBoard)) {
 	/* Great, we found our plugin */
-	g_warning("We found the correct plugin for board %s (type=%s)\n", gcomprisBoard->name, gcomprisBoard->type);
+	g_message("We found the correct plugin for board %s (type=%s)\n", gcomprisBoard->name, gcomprisBoard->type);
 
 	/* done in is_our_board gcomprisBoard->plugin = bp; */
 
@@ -356,7 +356,7 @@ gc_board_check_file(GcomprisBoard *gcomprisBoard)
 
 	return TRUE;
       } else {
-	g_warning("We found a plugin with the name %s but is_our_board() returned FALSE (type=%s)\n",
+	g_message("We found a plugin with the name %s but is_our_board() returned FALSE (type=%s)\n",
 		  gcomprisBoard->name,
 		  gcomprisBoard->type);
       }
@@ -365,7 +365,7 @@ gc_board_check_file(GcomprisBoard *gcomprisBoard)
 		gcomprisBoard->filename);
     }
   }
-  g_warning("No plugin library found for board type '%s', requested by '%s'",
+  g_message("No plugin library found for board type '%s', requested by '%s'",
 	    gcomprisBoard->type,  gcomprisBoard->filename);
 
   return FALSE;
@@ -394,6 +394,9 @@ gc_board_play(GcomprisBoard *gcomprisBoard)
       bp->start_board(gcomprisBoard);
       bp_data->playing = TRUE;
 
+      /* Force the bar to go on top of the activities canvas items */
+      gc_bar_hide (FALSE);
+
       return;
     }
 
@@ -410,7 +413,7 @@ gc_board_pause(int pause)
       if(gc_board_get_current_board_plugin()->pause_board)
 	gc_board_get_current_board_plugin()->pause_board(pause);
     }
-  else g_warning ("No boards to pause ?");
+  else g_message ("No boards to pause ?");
 }
 
 void
@@ -442,7 +445,7 @@ static gint next_board_callback_id = 0;
 
 void board_run_next_end()
 {
-  gtk_timeout_remove(next_board_callback_id);
+  g_source_remove(next_board_callback_id);
   next_board_callback_id = 0;
 
   if (next_board &&
@@ -463,8 +466,8 @@ void gc_board_run_next(GcomprisBoard *board)
 
   next_board = board;
 
-  next_board_callback_id = gtk_timeout_add (NEXT_TIME_DELAY,
-					    (GtkFunction) board_run_next_end,
-					    NULL);
+  next_board_callback_id = g_timeout_add (NEXT_TIME_DELAY,
+					  (GtkFunction) board_run_next_end,
+					  NULL);
 
 }
