@@ -31,6 +31,10 @@
 
 #include "gcompris.h"
 
+extern GooCanvas *canvas;
+
+typedef void (*sighandler_t)(int);
+
 /* GdkPixbuf RGBA C-Source image dump for a NULL image*/
 #ifdef __SUNPRO_C
 #pragma align 4 (null_img)
@@ -38,7 +42,7 @@
 #ifdef __GNUC__
 static const guint8 null_img[] __attribute__ ((__aligned__ (4))) =
 #else
-static const guint8 null_img[] =
+  static const guint8 null_img[] =
 #endif
 { ""
   /* Pixbuf magic (0x47646b50) */
@@ -56,7 +60,8 @@ static const guint8 null_img[] =
   /* pixel_data: */
   "%%%\0"};
 
-/** load a pixmap from the filesystem
+/** load a pixmap from the filesystem, return NULL if
+ *  not found and do not display an error message.
  *
  * \param format: If format contains $LOCALE, it will be first replaced by the current long locale
  *                and if not found the short locale name. It support printf formating.
@@ -64,6 +69,42 @@ static const guint8 null_img[] =
  *
  * \return a new allocated pixbuf or NULL
  */
+GdkPixbuf *gc_pixmap_load_or_null(const gchar *format, ...)
+{
+  va_list args;
+  gchar *filename;
+  gchar *pixmapfile;
+  GdkPixbuf *pixmap=NULL;
+
+  if (!format)
+    return NULL;
+
+  va_start (args, format);
+  pixmapfile = g_strdup_vprintf (format, args);
+  va_end (args);
+
+  /* Search */
+  filename = gc_file_find_absolute(pixmapfile);
+
+  if(filename)
+     pixmap = gdk_pixbuf_new_from_file(filename,NULL);
+
+  g_free(pixmapfile);
+  g_free(filename);
+
+
+  return(pixmap);
+}
+
+/** load a pixmap from the filesystem, if not found display
+ *  an error message and return an small 1x1 pixmap.
+ *
+ * \param format: If format contains $LOCALE, it will be first replaced by the current long locale
+ *                and if not found the short locale name. It support printf formating.
+ * \param ...:    additional params for the format (printf like)
+ *
+ * \return a new allocated pixbuf or a 1x1 pixmap
+ */
 GdkPixbuf *gc_pixmap_load(const gchar *format, ...)
 {
   va_list args;
@@ -82,7 +123,7 @@ GdkPixbuf *gc_pixmap_load(const gchar *format, ...)
   filename = gc_file_find_absolute(pixmapfile);
 
   if(filename)
-     pixmap = gdk_pixbuf_new_from_file(filename,NULL);
+    pixmap = gc_pixmap_load_or_null(filename);
 
   if (!filename || !pixmap)
     {
@@ -113,137 +154,92 @@ GdkPixbuf *gc_pixmap_load(const gchar *format, ...)
   return(pixmap);
 }
 
-/*************************************************************
- * colorshift a pixbuf
- * code taken from the gnome-panel of gnome-core
+/** load an svg image from the filesystem
+ *
+ * \param format: If format contains $LOCALE, it will be first replaced by the current long locale
+ *                and if not found the short locale name. It support printf formating.
+ * \param ...:    additional params for the format (printf like)
+ *
+ * \return a new allocated pixbuf or NULL
  */
-static void
-do_colorshift (GdkPixbuf *dest, GdkPixbuf *src, int shift)
+RsvgHandle *gc_rsvg_load(const gchar *format, ...)
 {
-  gint i, j;
-  gint width, height, has_alpha, srcrowstride, destrowstride;
-  guchar *target_pixels;
-  guchar *original_pixels;
-  guchar *pixsrc;
-  guchar *pixdest;
-  int val;
-  guchar r,g,b;
+  va_list args;
+  gchar *filename;
+  gchar *rsvghandlefile;
+  RsvgHandle *rsvghandle = NULL;
+  GError *error = NULL;
 
-  has_alpha = gdk_pixbuf_get_has_alpha (src);
-  width = gdk_pixbuf_get_width (src);
-  height = gdk_pixbuf_get_height (src);
-  srcrowstride = gdk_pixbuf_get_rowstride (src);
-  destrowstride = gdk_pixbuf_get_rowstride (dest);
-  target_pixels = gdk_pixbuf_get_pixels (dest);
-  original_pixels = gdk_pixbuf_get_pixels (src);
-
-  for (i = 0; i < height; i++) {
-    pixdest = target_pixels + i*destrowstride;
-    pixsrc = original_pixels + i*srcrowstride;
-    for (j = 0; j < width; j++) {
-      r = *(pixsrc++);
-      g = *(pixsrc++);
-      b = *(pixsrc++);
-      val = r + shift;
-      *(pixdest++) = CLAMP(val, 0, 255);
-      val = g + shift;
-      *(pixdest++) = CLAMP(val, 0, 255);
-      val = b + shift;
-      *(pixdest++) = CLAMP(val, 0, 255);
-      if (has_alpha)
-	*(pixdest++) = *(pixsrc++);
-    }
-  }
-}
-
-
-
-GdkPixbuf *
-make_hc_pixbuf(GdkPixbuf *pb, gint val)
-{
-  GdkPixbuf *new;
-  if(!pb)
+  if (!format)
     return NULL;
 
-  new = gdk_pixbuf_new(gdk_pixbuf_get_colorspace(pb),
-		       gdk_pixbuf_get_has_alpha(pb),
-		       gdk_pixbuf_get_bits_per_sample(pb),
-		       gdk_pixbuf_get_width(pb),
-		       gdk_pixbuf_get_height(pb));
-  do_colorshift(new, pb, val);
-  /*do_saturate_darken (new, pb, (int)(1.00*255), (int)(1.15*255));*/
+  va_start (args, format);
+  rsvghandlefile = g_strdup_vprintf (format, args);
+  va_end (args);
 
-  return new;
+  /* Search */
+  filename = gc_file_find_absolute(rsvghandlefile);
+
+  if(filename)
+    rsvghandle = rsvg_handle_new_from_file (filename, &error);
+
+  if (!filename || !rsvghandle)
+    {
+      char *str;
+
+      if(!rsvghandle)
+	g_warning("Loading image '%s' returned a null pointer", rsvghandlefile);
+      else
+	g_warning ("Couldn't find file %s !", rsvghandlefile);
+
+      str = g_strdup_printf("%s\n%s\n%s\n%s",
+			    _("Couldn't find or load the file"),
+			    rsvghandlefile,
+			    _("This activity is incomplete."),
+			    _("Exit it and report\nthe problem to the authors."));
+      gc_dialog (str, NULL);
+      g_free(rsvghandlefile);
+      g_free(str);
+
+      /* Create an empty rsvghandle because activities does not manage loading error */
+      return rsvg_handle_new();
+    }
+
+  g_free(rsvghandlefile);
+  g_free(filename);
+
+  return(rsvghandle);
 }
 
 /**
- * Free the highlight image from our image_focus system
- *
- * It must be called before assigning a new image to an item that
- * already has a focus enabled with gc_item_focus_event().
- */
-void
-gc_item_focus_free(GnomeCanvasItem *item, void *none)
-{
-  GdkPixbuf *pixbuf;
-
-  pixbuf = (GdkPixbuf *)g_object_get_data (G_OBJECT (item), "pixbuf_ref");
-  if(pixbuf)
-    {
-      g_object_set_data (G_OBJECT (item), "pixbuf_ref", NULL);
-      gdk_pixbuf_unref(pixbuf);
-    }
-}
-
-/**
- * Set the focus of the given image (highlight or not)
+ * Set the focus of the given item (highlight or not)
  *
  */
-void gc_item_focus_set(GnomeCanvasItem *item, gboolean focus)
+static void
+gc_item_focus_set(GooCanvasItem *item, gboolean focus)
 {
-  GdkPixbuf *dest = NULL;
-  GdkPixbuf *pixbuf;
-  GdkPixbuf *pixbuf_ref;
-
-  gtk_object_get (GTK_OBJECT (item), "pixbuf", &pixbuf, NULL);
-  g_return_if_fail (pixbuf != NULL);
-  gdk_pixbuf_unref(pixbuf);
-
-  /* Store the first pixbuf */
-  pixbuf_ref = (GdkPixbuf *)g_object_get_data (G_OBJECT (item), "pixbuf_ref");
-  if(!pixbuf_ref)
-    {
-      g_object_set_data (G_OBJECT (item), "pixbuf_ref", pixbuf);
-      pixbuf_ref = pixbuf;
-      gdk_pixbuf_ref(pixbuf);
-      g_signal_connect (item, "destroy",
- 			G_CALLBACK (gc_item_focus_free),
- 			NULL);
-
-    }
+  GooCanvasItem *highlight_item;
 
+  highlight_item = g_object_get_data (G_OBJECT(item),
+				      "highlight_item");
+  g_assert(highlight_item);
 
   switch (focus)
     {
     case TRUE:
-      dest = make_hc_pixbuf(pixbuf, 30);
-      gnome_canvas_item_set (item,
-			     "pixbuf", dest,
-			     NULL);
-
+      g_object_set (highlight_item,
+		    "visibility", GOO_CANVAS_ITEM_VISIBLE,
+		    NULL);
       break;
     case FALSE:
-      gnome_canvas_item_set (item,
-			     "pixbuf", pixbuf_ref,
-			     NULL);
+      g_object_set (highlight_item,
+		    "visibility", GOO_CANVAS_ITEM_INVISIBLE,
+		    NULL);
       break;
     default:
       break;
     }
 
-  if(dest!=NULL)
-    gdk_pixbuf_unref (dest);
-
 }
 
 /**
@@ -251,13 +247,13 @@ void gc_item_focus_set(GnomeCanvasItem *item, gboolean focus)
  * or the given one
  *
  */
-gint
-gc_item_focus_event(GnomeCanvasItem *item, GdkEvent *event,
-		    GnomeCanvasItem *dest_item)
+static gint
+gc_item_focus_event(GooCanvasItem *item, GooCanvasItem *target,
+		    GdkEvent *event,
+		    GooCanvasItem *target_item)
 {
-
-  if(dest_item!=NULL)
-    item = dest_item;
+  if(target_item != NULL)
+    item = target_item;
 
   switch (event->type)
     {
@@ -274,6 +270,109 @@ gc_item_focus_event(GnomeCanvasItem *item, GdkEvent *event,
   return FALSE;
 }
 
+/**
+ * Init an item so that it has a focus
+ * Optionnaly, provide a target_item that will be focused
+ * by events on source_item.
+ *
+ * Warning: You must call it each time the size of the focused
+ *          item size changes.
+ *
+ */
+#define GAP 4
+void gc_item_focus_init(GooCanvasItem *source_item,
+			GooCanvasItem *target_item)
+{
+  GooCanvasItem *highlight_item;
+  GooCanvasBounds bounds;
+  gboolean already_created = FALSE;
+
+  if(!target_item)
+    target_item = source_item;
+
+  goo_canvas_item_get_bounds(target_item, &bounds);
+  goo_canvas_convert_to_item_space(goo_canvas_item_get_canvas(target_item),
+				   goo_canvas_item_get_parent(target_item),
+				   &bounds.x1, &bounds.y1);
+  goo_canvas_convert_to_item_space(goo_canvas_item_get_canvas(target_item),
+				   goo_canvas_item_get_parent(target_item),
+				   &bounds.x2, &bounds.y2);
+  highlight_item = g_object_get_data (G_OBJECT(target_item),
+				      "highlight_item");
+
+  if(highlight_item)
+    {
+      already_created = TRUE;
+      goo_canvas_item_remove(highlight_item);
+    }
+
+  /* Create the highlight_item */
+  highlight_item =
+    goo_canvas_rect_new (goo_canvas_item_get_parent(target_item),
+			 bounds.x1 - GAP,
+			 bounds.y1 - GAP,
+			 bounds.x2 - bounds.x1 + GAP*2,
+			 bounds.y2 - bounds.y1 + GAP*2,
+			 "stroke_color_rgba", 0xFFFFFFFFL,
+			 "fill_color_rgba", 0xFF000090L,
+			 "line-width", (double) 2,
+			 "radius-x", (double) 10,
+			 "radius-y", (double) 10,
+			 NULL);
+
+  g_object_set_data (G_OBJECT(target_item), "highlight_item",
+		     highlight_item);
+  goo_canvas_item_lower(highlight_item, target_item);
+  g_object_set (highlight_item,
+  		"visibility", GOO_CANVAS_ITEM_INVISIBLE,
+  		NULL);
+
+  /* Avoid double connection */
+  g_signal_handlers_disconnect_by_func(source_item,
+				       (GtkSignalFunc) gc_item_focus_event,
+				       target_item);
+
+  /* connect source to target */
+  g_signal_connect(source_item, "enter_notify_event",
+		   (GtkSignalFunc) gc_item_focus_event,
+		   target_item);
+  g_signal_connect(source_item, "leave_notify_event",
+		   (GtkSignalFunc) gc_item_focus_event,
+		   target_item);
+}
+
+/**
+ * gc_item_focus_remove
+ *
+ * Remove a previously set of item focus
+ *
+ * @param[in] source_item is the same as the one passed to
+ *            gc_item_focus_init()
+ * @param[in] target_itemis the same as the one passed to
+ *            gc_item_focus_init()
+ */
+void gc_item_focus_remove(GooCanvasItem *source_item,
+			  GooCanvasItem *target_item)
+{
+  GooCanvasItem *highlight_item;
+
+  if(!target_item)
+    target_item = source_item;
+
+  g_signal_handlers_disconnect_by_func(source_item,
+				       (GtkSignalFunc) gc_item_focus_event,
+				       target_item);
+
+  highlight_item = g_object_get_data (G_OBJECT(target_item),
+				      "highlight_item");
+
+  if(highlight_item)
+    goo_canvas_item_remove(highlight_item);
+
+  g_object_set_data (G_OBJECT(target_item), "highlight_item",
+		     NULL);
+}
+
 /*
  * Return a new copy of the given string in which it has
  * changes '\''n' to '\n'.
@@ -303,71 +402,66 @@ gchar *reactivate_newline(char *str)
 }
 
 /* ======================================= */
-void gc_item_absolute_move(GnomeCanvasItem *item, int x, int y) {
-  double dx1, dy1, dx2, dy2;
-  gnome_canvas_item_get_bounds(item, &dx1, &dy1, &dx2, &dy2);
-  gnome_canvas_item_move(item, ((double)x)-dx1, ((double)y)-dy1);
+/* Any previous transformation are reseted first. */
+void gc_item_absolute_move(GooCanvasItem *item, int x, int y)
+{
+  GooCanvasBounds bounds;
+
+  goo_canvas_item_set_transform(item, NULL);
+  goo_canvas_item_get_bounds(item, &bounds);
+  goo_canvas_item_translate(item, ((double)x)-bounds.x1, ((double)y)-bounds.y1);
 }
 
 /* ======================================= */
 /** As gnome does not implement its own API : gc_item_rotate
-   we have to do it ourselves ....
-   IMPORTANT NOTE : This is designed for an item with "anchor" =  GTK_ANCHOR_CENTER
-   rotation is clockwise if angle > 0
+    we have to do it ourselves ....
+    rotation is clockwise if angle > 0
 */
 void
-gc_item_rotate(GnomeCanvasItem *item, double angle) {
-  double r[6],t[6], x1, x2, y1, y2;
-
-  gnome_canvas_item_get_bounds( item, &x1, &y1, &x2, &y2 );
-  art_affine_translate( t , -(x2+x1)/2, -(y2+y1)/2 );
-  art_affine_rotate( r, angle );
-  art_affine_multiply( r, t, r);
-  art_affine_translate( t , (x2+x1)/2, (y2+y1)/2 );
-  art_affine_multiply( r, r, t);
-
-  gnome_canvas_item_affine_absolute(item, r );
+gc_item_rotate(GooCanvasItem *item, double angle) {
+  GooCanvasBounds bounds;
+  goo_canvas_item_get_bounds (item, &bounds);
+  goo_canvas_item_rotate(item, angle,
+			 bounds.x1+(bounds.x2-bounds.x1)/2,
+			 bounds.y1+(bounds.y2-bounds.y1)/2);
 }
 
 /* As gnome does not implement its own API : gc_item_rotate_relative
    we have to do it ourselves ....
    IMPORTANT NOTE : This is designed for an item with "anchor" =  GTK_ANCHOR_CENTER
    rotation is clockwise if angle > 0
- */
+*/
 void
-gc_item_rotate_relative(GnomeCanvasItem *item, double angle) {
+gc_item_rotate_relative(GooCanvasItem *item, double angle)
+{
   double x1, x2, y1, y2;
   double tx1, tx2, ty1, ty2;
   double cx, cy;
-  double t;
-  double r[6];
 
-  //  gnome_canvas_item_get_bounds( item, &x1, &y1, &x2, &y2 );
-  /* WARNING: Do not use gnome_canvas_item_get_bounds which gives unpredictable results */
-  if(GNOME_IS_CANVAS_LINE(item)) {
-    GnomeCanvasPoints	*points;
-    gtk_object_get (GTK_OBJECT (item), "points", &points, NULL);
+  //  goo_canvas_item_get_bounds( item, &x1, &y1, &x2, &y2 );
+  /* WARNING: Do not use goo_canvas_item_get_bounds which gives unpredictable results */
+  if(GOO_IS_CANVAS_POLYLINE(item)) {
+    GooCanvasPoints	*points;
+    g_object_get (item, "points", &points, NULL);
     x1 = points->coords[0];
     y1 = points->coords[1];
     x2 = points->coords[2];
     y2 = points->coords[3];
-  } else if(GNOME_IS_CANVAS_PIXBUF(item)){
-    gtk_object_get (GTK_OBJECT (item), "x", &x1, NULL);
-    gtk_object_get (GTK_OBJECT (item), "y", &y1, NULL);
-    gtk_object_get (GTK_OBJECT (item), "width",  &x2, NULL);
-    gtk_object_get (GTK_OBJECT (item), "height", &y2, NULL);
+  } else if(GOO_IS_CANVAS_IMAGE(item)
+	    || GOO_IS_CANVAS_RECT(item)) {
+    g_object_get (item, "x", &x1, NULL);
+    g_object_get (item, "y", &y1, NULL);
+    g_object_get (item, "width",  &x2, NULL);
+    g_object_get (item, "height", &y2, NULL);
     x2 += x1;
     y2 += y1;
-  } else if(GNOME_IS_CANVAS_GROUP(item)){
-    gtk_object_get (GTK_OBJECT (item), "x", &x1, NULL);
-    gtk_object_get (GTK_OBJECT (item), "y", &y1, NULL);
+  } else if(GOO_IS_CANVAS_GROUP(item)){
+    g_object_get (item, "x", &x1, NULL);
+    g_object_get (item, "y", &y1, NULL);
     x2 = x1;
     y2 = y1;
   } else {
-    gtk_object_get (GTK_OBJECT (item), "x1", &x1, NULL);
-    gtk_object_get (GTK_OBJECT (item), "y1", &y1, NULL);
-    gtk_object_get (GTK_OBJECT (item), "x2", &x2, NULL);
-    gtk_object_get (GTK_OBJECT (item), "y2", &y2, NULL);
+    g_assert(FALSE);
   }
 
   tx1 = x1;
@@ -384,130 +478,74 @@ gc_item_rotate_relative(GnomeCanvasItem *item, double angle) {
   cx = (x2+x1)/2;
   cy = (y2+y1)/2;
 
-  /* Taken from anim by Yves Combe
-   * This matrix rotate around ( cx, cy )
-   * This is the result of the product:
-   *            T_{-c}             Rot (t)                 T_c
-   *
-   *       1    0   cx       cos(t) -sin(t)    0        1    0  -cx
-   *       0    1   cy  by   sin(t)  cos(t)    0   by   0    1  -cy
-   *       0    0    1         0       0       1        0    0   1
-   */
+  goo_canvas_item_rotate(item, angle,
+			 x1+(x2-x1)/2,
+			 y1+(y2-y1)/2);
 
-  t = M_PI*angle/180.0;
-
-  r[0] = cos(t);
-  r[1] = sin(t);
-  r[2] = -sin(t);
-  r[3] = cos(t);
-  r[4] = (1-cos(t))*cx + sin(t)*cy;
-  r[5] = -sin(t)*cx + (1 - cos(t))*cy;
-
-  gnome_canvas_item_affine_relative(item, r );
 }
 
 /** rotates an item around the center (x,y), relative to the widget's coordinates
+ * Any previous transformation are reseted first.
  */
 void
-gc_item_rotate_with_center(GnomeCanvasItem *item, double angle, int x, int y) {
-  double r[6],t[6], x1, x2, y1, y2, tx, ty;
+gc_item_rotate_with_center(GooCanvasItem *item, double angle, int x, int y)
+{
+  GooCanvasBounds bounds;
 
-  gnome_canvas_item_get_bounds( item, &x1, &y1, &x2, &y2 );
-  tx = x1 + x;
-  ty = y1 + y;
-  art_affine_translate( t , -tx, -ty );
-  art_affine_rotate( r, angle );
-  art_affine_multiply( r, t, r);
-  art_affine_translate( t , tx, ty );
-  art_affine_multiply( r, r, t);
-
-  gnome_canvas_item_affine_absolute(item, r );
+  goo_canvas_item_set_transform(item, NULL);
+  goo_canvas_item_get_bounds( item, &bounds );
+  goo_canvas_item_rotate(item, angle, bounds.x1+x, bounds.y1+y);
 }
 
 /** rotates an item around the center (x,y), relative to the widget's coordinates
  *  The rotation is relative to the previous rotation
  */
 void
-gc_item_rotate_relative_with_center(GnomeCanvasItem *item, double angle, int x, int y) {
-  double r[6],t[6], x1, x2, y1, y2, tx, ty;
-
-  gnome_canvas_item_get_bounds( item, &x1, &y1, &x2, &y2 );
-  tx = x1 + x;
-  ty = y1 + y;
-  art_affine_translate( t , -tx, -ty );
-  art_affine_rotate( r, angle );
-  art_affine_multiply( r, t, r);
-  art_affine_translate( t , tx, ty );
-  art_affine_multiply( r, r, t);
-
-  gnome_canvas_item_affine_relative(item, r );
-}
-
-/**
- * Display the number of stars representing the difficulty level at the x,y location
- * The stars are created in a group 'parent'
- * The new group in which the stars are created is returned.
- * This is only usefull for the menu plugin and the configuration dialog box.
- */
-GnomeCanvasGroup *gc_difficulty_display(GnomeCanvasGroup *parent,
-						    double x, double y,
-						    double ratio,
-						    gint difficulty)
+gc_item_rotate_relative_with_center(GooCanvasItem *item, double angle, int x, int y)
 {
-  GdkPixbuf *pixmap = NULL;
-  GnomeCanvasGroup *stars_group = NULL;
-  GnomeCanvasPixbuf *item = NULL;
-  gchar *filename = NULL;
+  double x1, x2, y1, y2;
 
-  if(difficulty==0 || difficulty>6)
-    return NULL;
+  if(GOO_IS_CANVAS_POLYLINE(item)) {
+    GooCanvasPoints *points;
+    g_object_get (item, "points", &points, NULL);
+    x1 = points->coords[0];
+    y1 = points->coords[1];
+    x2 = points->coords[2];
+    y2 = points->coords[3];
+  } else if(GOO_IS_CANVAS_IMAGE(item) || GOO_IS_CANVAS_RECT(item)) {
+    g_object_get (item, "x", &x1, NULL);
+    g_object_get (item, "y", &y1, NULL);
+    g_object_get (item, "width",  &x2, NULL);
+    g_object_get (item, "height", &y2, NULL);
+    x2 += x1 + (x2 - x1);
+    y2 += y1 + (y2 - y1);
+  } else if(GOO_IS_CANVAS_GROUP(item)){
+    g_object_get (item, "x", &x1, NULL);
+    g_object_get (item, "y", &y1, NULL);
+    x2 = x1;
+    y2 = y1;
+  } else {
+    g_object_get (item, "x1", &x1, NULL);
+    g_object_get (item, "y1", &y1, NULL);
+    g_object_get (item, "x2", &x2, NULL);
+    g_object_get (item, "y2", &y2, NULL);
+  }
 
-  filename = g_strdup_printf("difficulty_star%d.png", difficulty);
-  pixmap   = gc_skin_pixmap_load(filename);
-  g_free(filename);
-
-  if(!pixmap)
-    return NULL;
-
-  stars_group = GNOME_CANVAS_GROUP(
-				  gnome_canvas_item_new (parent,
-							 gnome_canvas_group_get_type (),
-							 "x", (double) 0,
-							 "y", (double) 0,
-							 NULL));
-
-  item = GNOME_CANVAS_PIXBUF(gnome_canvas_item_new (stars_group,
-						    gnome_canvas_pixbuf_get_type (),
-						    "pixbuf", pixmap,
-						    "x", x,
-						    "y", y,
-						    "width", (double) gdk_pixbuf_get_width(pixmap) * ratio,
-						    "height", (double) gdk_pixbuf_get_height(pixmap) * ratio,
-						    "width_set", TRUE,
-						    "height_set", TRUE,
-						    NULL));
-
-  gtk_signal_connect(GTK_OBJECT(item), "event",
-		     (GtkSignalFunc) gc_item_focus_event,
-		     NULL);
-
-  gdk_pixbuf_unref(pixmap);
-
-  return(stars_group);
+  goo_canvas_item_rotate(item, angle, x1+x, y1+y);
 }
 
 gchar *g_utf8_strndup(gchar* utf8text, gint n)
 {
- gchar* result;
+  gchar* result;
 
- gint len = g_utf8_strlen(utf8text, -1);
+  gint len = g_utf8_strlen(utf8text, -1);
 
- if( n < len && n > 0 )
-   len = n;
+  if( n < len && n > 0 )
+    len = n;
 
- result = g_strndup(utf8text, g_utf8_offset_to_pointer(utf8text, len) - utf8text);
+  result = g_strndup(utf8text, g_utf8_offset_to_pointer(utf8text, len) - utf8text);
 
- return result;
+  return result;
 }
 
 /** \brief search a given relative file in all gcompris dir it could be found
@@ -537,10 +575,8 @@ gc_file_find_absolute(const gchar *format, ...)
   va_end (args);
 
   /* Check it's already found */
-  if( g_file_test (filename, G_FILE_TEST_EXISTS))
-    {
-      return filename;
-    }
+  if( g_file_test (filename, G_FILE_TEST_EXISTS) )
+    return filename;
 
   /*
    * Search it on the file system
@@ -550,6 +586,7 @@ gc_file_find_absolute(const gchar *format, ...)
   	dir_to_search[i++] = "";
   dir_to_search[i++] = properties->user_dir;
   dir_to_search[i++] = properties->package_data_dir;
+  dir_to_search[i++] = properties->package_skin_dir;
   dir_to_search[i++] = NULL;
 
   absolute_filename = g_strdup(filename);
@@ -576,42 +613,25 @@ gc_file_find_absolute(const gchar *format, ...)
 	      g_free(filename2);
 	      goto FOUND;
 	    }
-      g_free(absolute_filename);
-	  /* Now check if this file is on the net */
-	  if((absolute_filename = gc_net_get_url_from_file(filename2, NULL)))
-	    {
-	      g_strfreev(tmp);
-	      g_free(filename2);
-	      goto FOUND;
-	    }
-
-      g_free(filename2);
-      g_free(absolute_filename);
+	  g_free(filename2);
 	  /* Try the short locale */
 	  if(g_strv_length(tmp)>1)
 	    {
 	      locale[2] = '\0';
 	      filename2 = g_strjoinv(locale, tmp);
 	      g_strfreev(tmp);
+	      g_free(absolute_filename);
 	      absolute_filename = g_strdup_printf("%s/%s", dir_to_search[i], filename2);
 	      if(g_file_test (absolute_filename, G_FILE_TEST_EXISTS))
 		{
 		  g_free(filename2);
 		  goto FOUND;
 		}
-	      g_free(absolute_filename);
-
-	      /* Now check if this file is on the net */
-	      if((absolute_filename = gc_net_get_url_from_file(filename2, NULL)))
-		{
-		  g_free(filename2);
-		  goto FOUND;
-		}
-        g_free(filename2);
+	      g_free(filename2);
 
 	    }
-      else
-          g_strfreev(tmp);
+	  else
+	    g_strfreev(tmp);
 	}
       else
 	{
@@ -619,11 +639,6 @@ gc_file_find_absolute(const gchar *format, ...)
 
 	  if(g_file_test (absolute_filename, G_FILE_TEST_EXISTS))
 	    goto FOUND;
-    g_free(absolute_filename);
-	  /* Now check if this file is on the net */
-	  if((absolute_filename = gc_net_get_url_from_file(filename, NULL)))
-	    goto FOUND;
-      g_free(absolute_filename);
 	}
 
       i++;
@@ -635,7 +650,9 @@ gc_file_find_absolute(const gchar *format, ...)
 
  FOUND:
   g_free(filename);
-  return absolute_filename;
+  char *abs_name = realpath(absolute_filename, NULL);
+  g_free(absolute_filename);
+  return abs_name;
 }
 
 gchar*
@@ -701,3 +718,108 @@ gc_activity_intro_play (GcomprisBoard *gcomprisBoard)
   gc_sound_play_ogg(str, NULL);
   g_free(str);
 }
+
+/** Display a button with the given text
+ *
+ * \param x the x coordinate of the button
+ * \param y the y coordinate of the button
+ * \param button_file the image file to use as the button
+ * \param text is the text to display in the button
+ * \param process is the callback function
+ * \param data is the user data passed to the callback function
+ *
+ * \return void
+ */
+void
+gc_util_button_text(GooCanvasItem *rootitem,
+		    guint x, guint y,
+		    char *button_file,
+		    char *text,
+		    GtkSignalFunc process,
+		    gpointer data)
+{
+  GdkPixbuf *pixmap;
+  GooCanvasItem *item;
+  GooCanvasItem *item_text;
+
+  /* The Button */
+  pixmap = gc_skin_pixmap_load(button_file);
+  item = goo_canvas_image_new (rootitem,
+			       pixmap,
+			       x,
+			       y,
+			       NULL);
+  g_signal_connect(item,
+		   "button_press_event",
+		   (GtkSignalFunc) process, data);
+  gc_item_focus_init(item, NULL);
+
+  /* The Text */
+  item_text =
+    goo_canvas_text_new (rootitem,
+			 text,
+			 x + (double)gdk_pixbuf_get_width(pixmap)/2,
+			 y + 24,
+			 -1,
+			 GTK_ANCHOR_CENTER,
+			 "font", gc_skin_font_board_small,
+			 "fill_color_rgba", gc_skin_color_text_button,
+			 NULL);
+  g_signal_connect(item_text,
+		   "button_press_event",
+		   process, data);
+  gc_item_focus_init(item_text, item);
+  gdk_pixbuf_unref(pixmap);
+}
+
+/** Display a button with the given text (BY SKIN'S SVG ID)
+ *
+ * \param x the x coordinate of the button
+ * \param y the y coordinate of the button
+ * \param button_file the image file to use as the button
+ * \param text is the text to display in the button
+ * \param process is the callback function
+ * \param data is the user data passed to the callback function
+ *
+ * \return void
+ */
+void
+gc_util_button_text_svg(GooCanvasItem *rootitem,
+			guint x, guint y,
+			char *button_id,
+			char *text,
+			GtkSignalFunc process,
+			gpointer data)
+{
+  GooCanvasItem *item;
+  GooCanvasItem *item_text;
+
+  /* The Button */
+  item = goo_canvas_svg_new (rootitem,
+			     gc_skin_rsvg_get(),
+			     "svg-id", button_id,
+			     "autocrop", TRUE,
+			     NULL);
+  SET_ITEM_LOCATION_CENTER(item, x, y);
+
+  g_signal_connect(item,
+		   "button_press_event",
+		   (GtkSignalFunc) process, data);
+  gc_item_focus_init(item, NULL);
+
+  /* The Text */
+  item_text =
+    goo_canvas_text_new (rootitem,
+			 text,
+			 x,
+			 y,
+			 -1,
+			 GTK_ANCHOR_CENTER,
+			 "font", gc_skin_font_board_small,
+			 "fill_color_rgba", gc_skin_color_text_button,
+			 NULL);
+  g_signal_connect(item_text,
+		   "button_press_event",
+		   process, data);
+  gc_item_focus_init(item_text, item);
+}
