@@ -1,6 +1,6 @@
 /* gcompris - gcompris_db.c
  *
- * Copyright (C) 2000 Bruno Coudoin
+ * Copyright (C) 2000, 2008 Bruno Coudoin
  *
  *   This program is free software; you can redistribute it and/or modify
  *   it under the terms of the GNU General Public License as published by
@@ -21,6 +21,13 @@
 #include "gcompris.h"
 #include <glib/gstdio.h>
 
+#ifdef USE_SQLITE
+static gboolean disable_database;
+#define SUPPORT_OR_RETURN(rv)   {if(disable_database) return rv;}
+#else
+#define SUPPORT_OR_RETURN(rv)   { return rv; }
+#endif
+
 #ifdef USE_SQLITE
 static char *escape_quote(const char *input);
 static sqlite3 *gcompris_db=NULL;
@@ -116,9 +123,12 @@ static sqlite3 *gcompris_db=NULL;
      END;"
 
 
-int gc_db_init()
+gboolean gc_db_init(gboolean disable_database_)
 {
+
 #ifdef USE_SQLITE
+  disable_database = disable_database_;
+  SUPPORT_OR_RETURN(FALSE);
   gboolean creation = FALSE;
   char *zErrMsg;
   char **result;
@@ -147,19 +157,19 @@ int gc_db_init()
     /* if size of file is null, we recreate the tables */
     if (buf.st_size == 0){
       creation = TRUE;
-      g_warning("Database file is empty! Trying to create table...");
+      g_message("Database file is empty! Trying to create table...");
     }
   }
 #endif
 
   rc = sqlite3_open(properties->database, &gcompris_db);
   if( rc ){
-    g_warning("Can't open database %s : %s\n", properties->database, sqlite3_errmsg(gcompris_db));
+    g_message("Can't open database %s : %s\n", properties->database, sqlite3_errmsg(gcompris_db));
     sqlite3_close(gcompris_db);
     exit(1);
   }
 
-  g_warning("Database %s opened", properties->database);
+  g_message("Database %s opened", properties->database);
 
   if (creation){
     /* create all tables needed */
@@ -234,7 +244,7 @@ int gc_db_init()
       g_error("SQL error: %s\n", zErrMsg);
     }
 
-    g_warning("Database tables created");
+    g_message("Database tables created");
 
     request = g_strdup_printf(SET_VERSION(VERSION));
 
@@ -295,7 +305,7 @@ int gc_db_init()
     if (!(strcmp(result[1],"ok")==0))
       g_error("DATABASE integrity check returns %s \n", result[1]);
 
-    g_warning("Database Integrity ok");
+    g_message("Database Integrity ok");
     sqlite3_free_table(result);
 
     rc = sqlite3_get_table(gcompris_db,
@@ -310,7 +320,7 @@ int gc_db_init()
     }
 
     if (strcmp(result[1],VERSION)!=0)
-      g_warning("Running GCompris is %s, but database version is %s", VERSION, result[1]);
+      g_message("Running GCompris is %s, but database version is %s", VERSION, result[1]);
     sqlite3_free_table(result);
 
     /* Schema upgrade */
@@ -329,7 +339,7 @@ int gc_db_init()
     sqlite3_free_table(result);
     if(version <= 16)
       {
-	g_warning("Upgrading from <16 schema version\n");
+	g_message("Upgrading from <16 schema version\n");
 	rc = sqlite3_exec(gcompris_db,CREATE_TABLE_LOGS, NULL,  0, &zErrMsg);
 	if( rc!=SQLITE_OK ) {
 	  g_error("SQL error: %s\n", zErrMsg);
@@ -343,21 +353,25 @@ int gc_db_init()
 #endif
 }
 
-void gc_db_exit()
+gboolean gc_db_exit()
 {
+  SUPPORT_OR_RETURN(FALSE);
+
 #ifdef USE_SQLITE
   sqlite3_close(gcompris_db);
-  g_warning("Database closed");
+  g_message("Database closed");
+  return TRUE;
 #endif
 }
 
 #define BOARDS_SET_DATE(date)				\
   "UPDATE informations SET init_date=\'%s\';",date
 
-void gc_db_set_date(gchar *date)
+gboolean gc_db_set_date(gchar *date)
 {
-#ifdef USE_SQLITE
+  SUPPORT_OR_RETURN(FALSE);
 
+#ifdef USE_SQLITE
   char *zErrMsg;
   char **result;
   int rc;
@@ -380,14 +394,17 @@ void gc_db_set_date(gchar *date)
 
   sqlite3_free_table(result);
 
+  return TRUE;
 #endif
 }
 
 #define BOARDS_UPDATE_VERSION(version)				\
   "UPDATE informations SET gcompris_version=\'%s\';",version
 
-void gc_db_set_version(gchar *version)
+gboolean gc_db_set_version(gchar *version)
 {
+  SUPPORT_OR_RETURN(FALSE);
+
 #ifdef USE_SQLITE
 
   char *zErrMsg;
@@ -412,6 +429,7 @@ void gc_db_set_version(gchar *version)
 
   sqlite3_free_table(result);
 
+  return TRUE;
 #endif
 }
 
@@ -419,6 +437,7 @@ void gc_db_set_version(gchar *version)
   "SELECT gcompris_version, init_date FROM informations;"
 gboolean gc_db_check_boards()
 {
+  SUPPORT_OR_RETURN(FALSE);
 #ifdef USE_SQLITE
 
   char *zErrMsg;
@@ -444,8 +463,6 @@ gboolean gc_db_check_boards()
   sqlite3_free_table(result);
 
   return ret_value;
-#else
-  return FALSE;
 #endif
 }
 
@@ -466,7 +483,7 @@ gboolean gc_db_check_boards()
   "SELECT board_id FROM boards WHERE name=\'%s\';",n
 
 
-void
+gboolean
 gc_db_board_update(guint *board_id,
 		   guint *section_id,
 		   gchar *name,
@@ -488,6 +505,8 @@ gc_db_board_update(guint *board_id,
 		   gchar *credit
 		   )
 {
+  SUPPORT_OR_RETURN(FALSE);
+
 #ifdef USE_SQLITE
 
   char *zErrMsg;
@@ -632,6 +651,7 @@ gc_db_board_update(guint *board_id,
 
   sqlite3_free(request);
 
+  return TRUE;
 #endif
 }
 
@@ -641,6 +661,8 @@ gc_db_board_update(guint *board_id,
 
 GList *gc_menu_load_db(GList *boards_list)
 {
+  SUPPORT_OR_RETURN(NULL);
+
 #ifdef USE_SQLITE
 
   GcomprisProperties	*properties = gc_prop_get();
@@ -685,11 +707,6 @@ GList *gc_menu_load_db(GList *boards_list)
     /* From DB we have only package_data_dir. */
     gcomprisBoard->board_dir = g_strdup(properties->package_data_dir);
 
-    /* Fixed since I use the canvas own pixel_per_unit scheme */
-    gcomprisBoard->width  = BOARDWIDTH;
-    gcomprisBoard->height = BOARDHEIGHT;
-
-
     gcomprisBoard->board_id = atoi(result[i++]);
     gcomprisBoard->name = g_strdup(result[i++]);
     gcomprisBoard->section_id = atoi(result[i++]);
@@ -717,8 +734,6 @@ GList *gc_menu_load_db(GList *boards_list)
 
   return boards;
 
-#else
-  return NULL;
 #endif
 }
 
@@ -733,6 +748,8 @@ GList *gc_db_read_board_from_section(gchar *section)
 
 GList *gc_db_get_board_id(GList *list)
 {
+  SUPPORT_OR_RETURN(NULL);
+
 #ifdef USE_SQLITE
 
   GList *board_id_list = list;
@@ -768,19 +785,17 @@ GList *gc_db_get_board_id(GList *list)
 
   return  board_id_list;
 
-#else
-  return list;
 #endif
 }
 
 #define DELETE_BOARD(table, board_id)			\
   "DELETE FROM %s WHERE board_id=%d;", table, board_id
 
-void gc_db_remove_board(int board_id)
+gboolean gc_db_remove_board(int board_id)
 {
-#ifdef USE_SQLITE
-  g_warning("Supress board %d from db.", board_id);
+  SUPPORT_OR_RETURN(FALSE);
 
+#ifdef USE_SQLITE
   char *zErrMsg;
   char **result;
   int rc;
@@ -840,6 +855,8 @@ void gc_db_remove_board(int board_id)
   }
 
   g_free(request);
+
+  return TRUE;
 #endif
 }
 
@@ -858,6 +875,8 @@ void gc_db_remove_board(int board_id)
 
 GcomprisProfile *gc_db_get_profile_from_id(gint profile_id)
 {
+  SUPPORT_OR_RETURN(FALSE);
+
 #ifdef USE_SQLITE
   GcomprisProfile *profile = NULL;
 
@@ -915,7 +934,7 @@ GcomprisProfile *gc_db_get_profile_from_id(gint profile_id)
     g_free(request);
 
     if (nrow == 0){
-      g_warning("No users' groups for profile %s", profile->name);
+      g_message("No users' groups for profile %s", profile->name);
       profile->group_ids = NULL;
     } else {
       ids = NULL;
@@ -947,7 +966,7 @@ GcomprisProfile *gc_db_get_profile_from_id(gint profile_id)
     g_free(request);
 
     if (nrow == 0){
-      g_warning("No activities for profile %s", profile->name);
+      g_message("No activities for profile %s", profile->name);
       profile->activities = NULL;
     } else {
       ids = NULL;
@@ -965,8 +984,6 @@ GcomprisProfile *gc_db_get_profile_from_id(gint profile_id)
   }
 
   return profile;
-#else
-  return NULL;
 #endif
 }
 
@@ -979,6 +996,8 @@ GcomprisProfile *gc_db_get_profile_from_id(gint profile_id)
 GcomprisProfile *
 gc_db_profile_from_name_get(gchar *profile_name)
 {
+  SUPPORT_OR_RETURN(FALSE);
+
 #ifdef USE_SQLITE
   GcomprisProfile *profile = NULL;
 
@@ -1017,8 +1036,6 @@ gc_db_profile_from_name_get(gchar *profile_name)
 
 
   return profile;
-#else
-  return NULL;
 #endif
 }
 
@@ -1029,6 +1046,8 @@ gc_db_profile_from_name_get(gchar *profile_name)
 
 GcomprisProfile *gc_db_get_profile()
 {
+  SUPPORT_OR_RETURN(NULL);
+
 #ifdef USE_SQLITE
   char *zErrMsg;
   char **result;
@@ -1055,8 +1074,6 @@ GcomprisProfile *gc_db_get_profile()
 
   return gc_db_get_profile_from_id(profile_id);
 
-#else
-  return NULL;
 #endif
 }
 
@@ -1065,6 +1082,8 @@ GcomprisProfile *gc_db_get_profile()
 
 GList *gc_db_users_from_group_get(gint group_id)
 {
+  SUPPORT_OR_RETURN(NULL);
+
 #ifdef USE_SQLITE
   char *zErrMsg;
   char **result;
@@ -1092,7 +1111,7 @@ GList *gc_db_users_from_group_get(gint group_id)
   g_free(request);
 
   if (nrow == 0){
-    g_warning("No users in the group id %d", group_id);
+    g_message("No users in the group id %d", group_id);
   } else {
     i = ncolumn;
     while (i < (nrow +1)*ncolumn) {
@@ -1120,6 +1139,8 @@ GList *gc_db_users_from_group_get(gint group_id)
 
 GcomprisUser *gc_db_get_user_from_id(gint user_id)
 {
+  SUPPORT_OR_RETURN(NULL);
+
 #ifdef USE_SQLITE
   char *zErrMsg;
   char **result;
@@ -1146,7 +1167,7 @@ GcomprisUser *gc_db_get_user_from_id(gint user_id)
   g_free(request);
 
   if (nrow == 0){
-    g_warning("No user with id  %d", user_id);
+    g_message("No user with id  %d", user_id);
     return NULL;
   } else {
     i = ncolumn;
@@ -1162,8 +1183,6 @@ GcomprisUser *gc_db_get_user_from_id(gint user_id)
 
 
   return user ;
-#else
-  return NULL;
 #endif
 }
 
@@ -1175,6 +1194,8 @@ GcomprisUser *gc_db_get_user_from_id(gint user_id)
 
 GcomprisClass *gc_db_get_class_from_id(gint class_id)
 {
+  SUPPORT_OR_RETURN(NULL);
+
 #ifdef USE_SQLITE
   char *zErrMsg;
   char **result;
@@ -1202,7 +1223,7 @@ GcomprisClass *gc_db_get_class_from_id(gint class_id)
   g_free(request);
 
   if (nrow == 0){
-    g_warning("No class with id %d", class_id);
+    g_message("No class with id %d", class_id);
     return NULL;
     return NULL;
   } else {
@@ -1254,8 +1275,6 @@ GcomprisClass *gc_db_get_class_from_id(gint class_id)
   }
 
   return class ;
-#else
-  return NULL;
 #endif
 }
 
@@ -1269,11 +1288,14 @@ GcomprisClass *gc_db_get_class_from_id(gint class_id)
 #define UPDATE_KEY							\
   "UPDATE board_profile_conf SET conf_value=%Q WHERE profile_id=%d AND board_id=%d AND conf_key=%Q;"
 
-void gc_db_set_board_conf(GcomprisProfile *profile,
-			  GcomprisBoard  *board,
-			  gchar *key,
-			  gchar *value)
+gboolean
+gc_db_set_board_conf(GcomprisProfile *profile,
+		     GcomprisBoard  *board,
+		     gchar *key,
+		     gchar *value)
 {
+  SUPPORT_OR_RETURN(FALSE);
+
 #ifdef USE_SQLITE
   char *zErrMsg;
   char **result;
@@ -1343,16 +1365,21 @@ void gc_db_set_board_conf(GcomprisProfile *profile,
 
     sqlite3_free(request);
   }
+
+  return TRUE;
 #endif
 }
 
 #define GET_CONF(p, b)							\
   "SELECT conf_key, conf_value FROM board_profile_conf WHERE profile_id=%d AND board_id=%d;", p, b
 
-GHashTable *gc_db_conf_with_table_get(int profile_id, int board_id, GHashTable *table )
+GHashTable *gc_db_conf_with_table_get(int profile_id, int board_id,
+				      GHashTable *table )
 {
   GHashTable *hash_conf = table;
 
+  SUPPORT_OR_RETURN(hash_conf);
+
 #ifdef USE_SQLITE
   char *zErrMsg;
   char **result;
@@ -1365,7 +1392,7 @@ GHashTable *gc_db_conf_with_table_get(int profile_id, int board_id, GHashTable *
   request = g_strdup_printf(GET_CONF(profile_id,
 				     board_id));
 
-  g_warning ( "Request get_conf : %s", request);
+  g_message ( "Request get_conf : %s", request);
 
   rc = sqlite3_get_table(gcompris_db,
 			 request,
@@ -1387,25 +1414,26 @@ GHashTable *gc_db_conf_with_table_get(int profile_id, int board_id, GHashTable *
       g_hash_table_replace (hash_conf,
 			    g_strdup(result[i]),
 			    g_strdup(result[i+1]));
-      g_warning("get_conf: put key %s value %s in the hash",
+      g_message("get_conf: put key %s value %s in the hash",
 		result[i],
 		result[i+1]);
     }
   }
 
   sqlite3_free_table(result);
-#endif
+
   return hash_conf;
+#endif
 }
 
 GHashTable *gc_db_get_conf(GcomprisProfile *profile, GcomprisBoard  *board )
 {
   GHashTable *hash_result = g_hash_table_new_full(g_str_hash, g_str_equal, g_free, g_free);
 
+  SUPPORT_OR_RETURN(hash_result);
+
 #ifdef USE_SQLITE
   return gc_db_conf_with_table_get( profile->profile_id, board->board_id, hash_result) ;
-#else
-  return hash_result;
 #endif
 }
 
@@ -1441,6 +1469,8 @@ GHashTable *gc_db_get_board_conf()
 
 GList *gc_db_profiles_list_get()
 {
+  SUPPORT_OR_RETURN(NULL);
+
 #ifdef USE_SQLITE
 
 
@@ -1504,7 +1534,7 @@ GList *gc_db_profiles_list_get()
     g_free(request);
 
     if (nrow_ == 0){
-      g_warning("No users groups for profile %s", profile->name);
+      g_message("No users groups for profile %s", profile->name);
       profile->group_ids = NULL;
     } else {
       ids_ = NULL;
@@ -1537,7 +1567,7 @@ GList *gc_db_profiles_list_get()
     g_free(request);
 
     if (nrow_ == 0){
-      g_warning("No activities out for profile %s", profile->name);
+      g_message("No activities out for profile %s", profile->name);
       profile->activities = NULL;
     } else {
       ids_ = NULL;
@@ -1559,8 +1589,6 @@ GList *gc_db_profiles_list_get()
   sqlite3_free_table(result);
 
   return profiles_list;
-#else
-  return NULL;
 #endif
 }
 
@@ -1569,6 +1597,8 @@ GList *gc_db_profiles_list_get()
 
 GcomprisGroup *gc_db_get_group_from_id(int group_id)
 {
+  SUPPORT_OR_RETURN(NULL);
+
 #ifdef USE_SQLITE
 
   char *zErrMsg;
@@ -1597,7 +1627,7 @@ GcomprisGroup *gc_db_get_group_from_id(int group_id)
   g_free(request);
 
   if (nrow == 0){
-    g_warning("No group with id  %d", group_id);
+    g_message("No group with id  %d", group_id);
     return NULL;
   } else {
     i = ncolumn;
@@ -1614,8 +1644,6 @@ GcomprisGroup *gc_db_get_group_from_id(int group_id)
 
   return group ;
 
-#else
-  return NULL;
 #endif
 }
 
@@ -1624,6 +1652,8 @@ GcomprisGroup *gc_db_get_group_from_id(int group_id)
 
 GList *gc_db_get_groups_list()
 {
+  SUPPORT_OR_RETURN(NULL);
+
 #ifdef USE_SQLITE
   GList *groups_list = NULL;
 
@@ -1648,7 +1678,7 @@ GList *gc_db_get_groups_list()
   }
 
   if (nrow == 0){
-    g_warning("No groups !");
+    g_message("No groups !");
     return NULL;
   } else {
     i = ncolumn;
@@ -1668,9 +1698,6 @@ GList *gc_db_get_groups_list()
   }
 
   return groups_list;
-
-#else
-  return NULL;
 #endif
 }
 
@@ -1680,6 +1707,8 @@ GList *gc_db_get_groups_list()
 
 GcomprisBoard *gc_db_get_board_from_id(int board_id)
 {
+  SUPPORT_OR_RETURN(NULL);
+
 #ifdef USE_SQLITE
 
   GcomprisProperties	*properties = gc_prop_get();
@@ -1727,11 +1756,6 @@ GcomprisBoard *gc_db_get_board_from_id(int board_id)
   /* From DB we have only package_data_dir. */
   gcomprisBoard->board_dir = g_strdup(properties->package_data_dir);
 
-  /* Fixed since I use the canvas own pixel_per_unit scheme */
-  gcomprisBoard->width  = BOARDWIDTH;
-  gcomprisBoard->height = BOARDHEIGHT;
-
-
   gcomprisBoard->board_id = board_id;
   gcomprisBoard->name = g_strdup(result[i++]);
   gcomprisBoard->section_id = atoi(result[i++]);
@@ -1755,8 +1779,6 @@ GcomprisBoard *gc_db_get_board_from_id(int board_id)
   sqlite3_free_table(result);
 
   return gcomprisBoard;
-#else
-  return NULL;
 #endif
 }
 
@@ -1765,6 +1787,8 @@ GcomprisBoard *gc_db_get_board_from_id(int board_id)
 
 GList *gc_db_get_users_list()
 {
+  SUPPORT_OR_RETURN(NULL);
+
 #ifdef USE_SQLITE
   GList *users_list = NULL;
 
@@ -1789,7 +1813,7 @@ GList *gc_db_get_users_list()
   }
 
   if (nrow == 0){
-    g_warning("No users !");
+    g_message("No users !");
     return NULL;
   } else {
     i = ncolumn;
@@ -1809,9 +1833,6 @@ GList *gc_db_get_users_list()
   }
 
   return users_list;
-
-#else
-  return NULL;
 #endif
 }
 
@@ -1820,6 +1841,8 @@ GList *gc_db_get_users_list()
 
 GList *gc_db_get_classes_list()
 {
+  SUPPORT_OR_RETURN(NULL);
+
 #ifdef USE_SQLITE
   GList *classes_list = NULL;
 
@@ -1844,7 +1867,7 @@ GList *gc_db_get_classes_list()
   }
 
   if (nrow == 0){
-    g_warning("No groups !");
+    g_message("No groups !");
     return NULL;
   } else {
     i = ncolumn;
@@ -1862,9 +1885,6 @@ GList *gc_db_get_classes_list()
   }
 
   return classes_list;
-
-#else
-  return NULL;
 #endif
 }
 
@@ -1874,6 +1894,8 @@ GList *gc_db_get_classes_list()
 
 int gc_db_is_activity_in_profile(GcomprisProfile *profile, char *activity_name)
 {
+  SUPPORT_OR_RETURN(TRUE);
+
 #ifdef USE_SQLITE
   char *zErrMsg;
   char **result;
@@ -1905,20 +1927,19 @@ int gc_db_is_activity_in_profile(GcomprisProfile *profile, char *activity_name)
 
   /* IS NOT IN THE PROFILE */
   return FALSE;
-
-#else
-  return TRUE;
 #endif
 }
 
 /** \brief insert a new log in the database
  *
  */
-void gc_db_log(gchar *date, int duration,
-	       int user_id, int board_id,
-	       int level, int sublevel,
-	       int status, gchar *comment)
+gboolean gc_db_log(gchar *date, int duration,
+		   int user_id, int board_id,
+		   int level, int sublevel,
+		   int status, gchar *comment)
 {
+  SUPPORT_OR_RETURN(FALSE);
+
 #ifdef USE_SQLITE
   char *zErrMsg;
   int rc;
@@ -1936,6 +1957,8 @@ void gc_db_log(gchar *date, int duration,
 
   if(comment)
     g_free(comment_quoted);
+
+  return TRUE;
 #endif
 }
 
