@@ -1,6 +1,6 @@
 /* gcompris - menu.c
  *
- * Copyright (C) 2000-2006 Bruno Coudoin
+ * Copyright (C) 2000, 2008 Bruno Coudoin
  *
  *   This program is free software; you can redistribute it and/or modify
  *   it under the terms of the GNU General Public License as published by
@@ -209,7 +209,7 @@ _add_xml_to_data(xmlDocPtr doc, xmlNodePtr xmlnode, GNode * child,
 			credit
 			);
 
-    g_warning("db board written %d in %d  %s/%s",
+    g_message("db board written %d in %d  %s/%s",
 	      gcomprisBoard->board_id, gcomprisBoard->section_id,
 	      gcomprisBoard->section, gcomprisBoard->name);
 
@@ -270,8 +270,8 @@ _read_xml_file(GcomprisBoard *gcomprisBoard,
 
       if(!g_file_test ((filename), G_FILE_TEST_EXISTS))
 	{
-	  g_warning("Couldn't find file %s !", fname);
-	  g_warning("Couldn't find file %s !", filename);
+	  g_message("Couldn't find file %s !", fname);
+	  g_message("Couldn't find file %s !", filename);
 	  g_free(filename);
 	  g_free(gcomprisBoard);
 	  return NULL;
@@ -314,10 +314,6 @@ _read_xml_file(GcomprisBoard *gcomprisBoard,
   gcomprisBoard->gmodule      = NULL;
   gcomprisBoard->gmodule_file = NULL;
 
-  /* Fixed since I use the canvas own pixel_per_unit scheme */
-  gcomprisBoard->width  = BOARDWIDTH;
-  gcomprisBoard->height = BOARDHEIGHT;
-
   return gcomprisBoard;
 }
 
@@ -494,7 +490,6 @@ static GList *suppress_int_from_list(GList *list, int value)
     }
     cell = cell->next;
   }
-  g_warning("suppress_int_from_list value %d not found", value);
   return list;
 }
 
@@ -522,14 +517,14 @@ void gc_menu_load_dir(char *dirname, gboolean db){
   GList *list_old_boards_id = NULL;
 
   if (!g_file_test(dirname, G_FILE_TEST_IS_DIR)) {
-    g_warning("Failed to parse board in '%s' because it's not a directory\n", dirname);
+    g_message("Failed to parse board in '%s' because it's not a directory\n", dirname);
     return;
   }
 
   dir = g_dir_open(dirname, 0, NULL);
 
   if (!dir) {
-    g_warning("gc_menu_load : no menu found in %s", dirname);
+    g_message("gc_menu_load : no menu found in %s", dirname);
     return;
   } else {
     if (db)
@@ -633,7 +628,7 @@ void gc_menu_load()
     {
       int db = (gc_profile_get_current() ? TRUE: FALSE);
       properties->reread_menu = TRUE;
-      gc_menu_load_dir(properties->package_data_dir, db);
+      gc_menu_load_dir(properties->menu_dir, db);
 
 
       /* use GTimeVal for portability */
@@ -648,18 +643,11 @@ void gc_menu_load()
       g_date_set_time (today, time (NULL));
 #endif
       gchar date[11];
-      g_date_strftime (date, 11, "%F", today);
+      g_date_strftime (date, 11, "%Y-%m-%d", today);
       gc_db_set_date(date);
       gc_db_set_version(VERSION);
       g_date_free(today);
     }
-
-
-  if (properties->local_directory){
-    gchar *board_dir = g_strdup_printf("%s/boards/", properties->local_directory);
-    gc_menu_load_dir(board_dir, FALSE);
-    g_free(board_dir);
-  }
 }
 
 
