@@ -1,19 +1,19 @@
 /* gcompris - properties.c
  *
- * Copyright (C) 2000,2003 Bruno Coudoin
+ * Copyright (C) 2000, 2008 Bruno Coudoin
  *
- * This program is free software; you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 3 of the License, or
- * (at your option) any later version.
+ *   This program is free software; you can redistribute it and/or modify
+ *   it under the terms of the GNU General Public License as published by
+ *   the Free Software Foundation; either version 3 of the License, or
+ *   (at your option) any later version.
  *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
+ *   This program is distributed in the hope that it will be useful,
+ *   but WITHOUT ANY WARRANTY; without even the implied warranty of
+ *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ *   GNU General Public License for more details.
  *
- * You should have received a copy of the GNU General Public License
- * along with this program; if not, see <http://www.gnu.org/licenses/>.
+ *   You should have received a copy of the GNU General Public License
+ *   along with this program; if not, see <http://www.gnu.org/licenses/>.
  */
 
 #define G_STDIO_NO_WRAP_ON_UNIX
@@ -146,9 +146,7 @@ gc_prop_new ()
   tmp = (GcomprisProperties *) malloc (sizeof (GcomprisProperties));
   tmp->music		 = 1;
   tmp->fx		 = 1;
-  tmp->screensize	 = 1;
-  tmp->fullscreen	 = 0;
-  tmp->noxf86vm		 = FALSE;
+  tmp->fullscreen	 = 1;
   tmp->timer		 = 1;
   tmp->skin		 = g_strdup("babytoy");
   tmp->key		 = g_strdup("default");
@@ -160,7 +158,6 @@ gc_prop_new ()
   tmp->disable_config    = 0;				/* Used to remove the config button from the bar. Use it for kiosk mode */
   tmp->display_resource  = 0;
   tmp->root_menu         = g_strdup("/");
-  tmp->local_directory   = NULL;
   tmp->profile           = NULL;
   tmp->logged_user       = NULL;
 
@@ -168,14 +165,15 @@ gc_prop_new ()
   tmp->reread_menu       = FALSE;
   tmp->experimental      = FALSE;
 
-  tmp->server            = NULL;
-
   tmp->package_data_dir           = NULL;
+  tmp->package_skin_dir           = NULL;
   tmp->package_locale_dir         = NULL;
   tmp->package_plugin_dir         = NULL;
   tmp->package_python_plugin_dir  = NULL;
+  tmp->menu_dir			  = NULL;
   tmp->system_icon_dir            = NULL;
   tmp->cache_dir                  = NULL;
+  tmp->server	                  = NULL;
   tmp->drag_mode                  = GC_DRAG_MODE_GRAB;
 
   tmp->config_dir = gc_prop_default_config_directory_get();
@@ -358,7 +356,7 @@ gc_prop_load (GcomprisProperties *props, GCPropSourceConf source_conf)
 			 &length,
 			 NULL)) {
 
-    g_warning("Loading config file '%s'", config_file);
+    g_message("Loading config file '%s'", config_file);
 
     /* create a new scanner */
     scanner = g_scanner_new(NULL);
@@ -384,15 +382,9 @@ gc_prop_load (GcomprisProperties *props, GCPropSourceConf source_conf)
 	} else if(!strcmp(value.v_identifier, "fx")) {
 	  if(!scan_get_int(scanner, &props->fx))
 	    g_warning("Config file parsing error on token %s", token);
-	} else if(!strcmp(value.v_identifier, "screensize")) {
-	  if(!scan_get_int(scanner, &props->screensize))
-	    g_warning("Config file parsing error on token %s", token);
 	} else if(!strcmp(value.v_identifier, "fullscreen")) {
 	  if(!scan_get_int(scanner, &props->fullscreen))
 	    g_warning("Config file parsing error on token %s", token);
-	} else if(!strcmp(value.v_identifier, "noxf86vm")) {
-	  if(!scan_get_int(scanner, &props->noxf86vm))
-	    g_warning("Config file parsing error on token %s", token);
 	} else if(!strcmp(value.v_identifier, "timer")) {
 	  if(!scan_get_int(scanner, &props->timer))
 	    g_warning("Config file parsing error on token %s", token);
@@ -521,9 +513,11 @@ gc_prop_destroy (GcomprisProperties *props)
   if(!props)
     return;
   g_free(props->package_data_dir);
+  g_free(props->package_skin_dir);
   g_free(props->package_locale_dir);
   g_free(props->package_plugin_dir);
   g_free(props->package_python_plugin_dir);
+  g_free(props->menu_dir);
   g_free(props->system_icon_dir);
   g_free(props->cache_dir);
   g_free(props->locale);
@@ -537,7 +531,6 @@ gc_prop_destroy (GcomprisProperties *props)
   g_free(props->server);
   g_free(props->root_menu);
   g_free(props);
-  g_warning("properties free");
 }
 
 void
@@ -556,7 +549,6 @@ gc_prop_save (GcomprisProperties *props)
 
   fprintf(filefd, "%s=%d\n", "music",			props->music);
   fprintf(filefd, "%s=%d\n", "fx",			props->fx);
-  fprintf(filefd, "%s=%d\n", "screensize",		props->screensize);
   fprintf(filefd, "%s=%d\n", "fullscreen",		props->fullscreen);
   fprintf(filefd, "%s=%d\n", "timer",			props->timer);
 
