@@ -1,19 +1,19 @@
 /* gcompris - properties.h
  *
- * Copyright (C) 2000 Bruno Coudoin
+ * Copyright (C) 2000, 2008 Bruno Coudoin
  *
- * This program is free software; you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 3 of the License, or
- * (at your option) any later version.
+ *   This program is free software; you can redistribute it and/or modify
+ *   it under the terms of the GNU General Public License as published by
+ *   the Free Software Foundation; either version 3 of the License, or
+ *   (at your option) any later version.
  *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
+ *   This program is distributed in the hope that it will be useful,
+ *   but WITHOUT ANY WARRANTY; without even the implied warranty of
+ *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ *   GNU General Public License for more details.
  *
- * You should have received a copy of the GNU General Public License
- * along with this program; if not, see <http://www.gnu.org/licenses/>.
+ *   You should have received a copy of the GNU General Public License
+ *   along with this program; if not, see <http://www.gnu.org/licenses/>.
  */
 
 #ifndef _PROPERTIES_H_
@@ -31,8 +31,6 @@ typedef struct {
   gint		music;
   gint		fx;
   gint		fullscreen;
-  gint		noxf86vm;
-  gint		screensize;
   gint		defaultcursor;
   gint		timer;
   gint		filter_style;
@@ -42,11 +40,12 @@ typedef struct {
   gint		disable_config;
   gint		display_resource;
   gchar        *root_menu;
-  gchar        *local_directory;
   gchar        *package_data_dir;
+  gchar        *package_skin_dir;
   gchar        *package_locale_dir;
   gchar        *package_plugin_dir;
   gchar        *package_python_plugin_dir;
+  gchar        *menu_dir;
   gchar        *system_icon_dir;
   gchar        *cache_dir;
   gchar	       *locale;
@@ -63,7 +62,7 @@ typedef struct {
   /* this are set by gc_im_init() */
   GtkIMContext *context;
   gchar        *default_context;
-  gint         experimental;
+  gint          experimental;
   gchar        *server;
   gint		drag_mode;
 } GcomprisProperties;
