@@ -1,6 +1,6 @@
 /* gcompris - score.c
  *
- * Copyright (C) 2000 Bruno Coudoin
+ * Copyright (C) 2000, 2008 Bruno Coudoin
  *
  *   This program is free software; you can redistribute it and/or modify
  *   it under the terms of the GNU General Public License as published by
@@ -23,7 +23,7 @@
 
 #include "gcompris.h"
 
-static GnomeCanvasGroup *boardRootItem = NULL;
+static GooCanvasItem *boardRootItem = NULL;
 
 static guint x, y, max;
 static ScoreStyleList currentStyle;
@@ -31,7 +31,7 @@ static ScoreStyleList currentStyle;
 /*
  * Forward declarations
  */
-static void display_number(GnomeCanvasGroup *parent,
+static void display_number(GooCanvasItem *parent,
 			   guint x,
 			   guint y,
 			   char *operand_str);
@@ -69,7 +69,7 @@ void
 gc_score_end()
 {
   if(boardRootItem!=NULL)
-    gtk_object_destroy (GTK_OBJECT(boardRootItem));
+    goo_canvas_item_remove(boardRootItem);
 
   boardRootItem=NULL;
 }
@@ -79,33 +79,36 @@ gc_score_set(guint value)
 {
 
   if(boardRootItem!=NULL)
-    gtk_object_destroy (GTK_OBJECT(boardRootItem));
+    goo_canvas_item_remove(boardRootItem);
 
-  boardRootItem = GNOME_CANVAS_GROUP(
-				     gnome_canvas_item_new (
-							    gnome_canvas_root(gc_board_get_current()->canvas),
-							    gnome_canvas_group_get_type (),
-							    "x", (double) x,
-							    "y", (double) y,
-							    NULL));
+  boardRootItem = \
+    goo_canvas_group_new (goo_canvas_get_root_item(GOO_CANVAS(gc_board_get_current()->canvas)),
+			  NULL);
 
   switch(currentStyle) {
   case SCORESTYLE_NOTE :
     {
       gchar *tmp;
-      GdkPixbuf *button_pixmap = NULL;
+      GooCanvasItem *item;
+      GooCanvasBounds bounds;
 
-      button_pixmap = gc_skin_pixmap_load("button_large.png");
-      gnome_canvas_item_new (boardRootItem,
-			     gnome_canvas_pixbuf_get_type (),
-			     "pixbuf",  button_pixmap,
-			     "x",  (double) 0,
-			     "y",  (double) -gdk_pixbuf_get_height(button_pixmap)/2,
-			     NULL);
-      gdk_pixbuf_unref(button_pixmap);
+      item =
+	goo_canvas_svg_new (boardRootItem,
+			    gc_skin_rsvg_get(),
+			    "svg-id", "#BUTTON_TEXT",
+			    "autocrop", TRUE,
+			    NULL);
+      goo_canvas_item_get_bounds(item, &bounds);
+
+      SET_ITEM_LOCATION(item,
+			x,
+			y - (bounds.y2 - bounds.y1)/2 );
 
       tmp = g_strdup_printf("%d/%d", value, max);
-      display_number(boardRootItem, gdk_pixbuf_get_width(button_pixmap)+10, 0, tmp);
+      display_number(boardRootItem,
+		     x + (bounds.x2 - bounds.x1)/2,
+		     y - (bounds.y2 - bounds.y1)/2,
+		     tmp);
       g_free(tmp);
     }
     break;
@@ -120,33 +123,32 @@ gc_score_set(guint value)
 /*-------------------------------------------------------------------------------*/
 
 
-#define NUMBERSWIDTH       110
-
 static void
-display_number(GnomeCanvasGroup *parent,
+display_number(GooCanvasItem *parent,
 	       guint x,
 	       guint y,
 	       char *operand_str)
 {
 
-  x -= NUMBERSWIDTH;
+  goo_canvas_text_new (parent,
+		       operand_str,
+		       x+2,
+		       y+2,
+		       -1,
+		       GTK_ANCHOR_NORTH,
+		       "alignment", PANGO_ALIGN_CENTER,
+		       "font", gc_skin_font_board_huge_bold,
+		       "fill-color-rgba", 0x7a8699FF,
+		       NULL);
 
-  gnome_canvas_item_new (parent,
-			 gnome_canvas_text_get_type (),
-			 "text", operand_str,
-			 "font", gc_skin_font_board_huge_bold,
-			 "x", (double) x+2,
-			 "y", (double) y+2,
-			 "anchor", GTK_ANCHOR_CENTER,
-			 "fill_color_rgba", 0x7a8699FF,
-			 NULL);
-  gnome_canvas_item_new (parent,
-			 gnome_canvas_text_get_type (),
-			 "text", operand_str,
-			 "font", gc_skin_font_board_huge_bold,
-			 "x", (double) x,
-			 "y", (double) y,
-			 "anchor", GTK_ANCHOR_CENTER,
-			 "fill_color_rgba", 0xe5e532FF,
-			 NULL);
+  goo_canvas_text_new (parent,
+		       operand_str,
+		       x,
+		       y,
+		       -1,
+		       GTK_ANCHOR_NORTH,
+		       "alignment", PANGO_ALIGN_CENTER,
+		       "font", gc_skin_font_board_huge_bold,
+		       "fill-color-rgba", 0xe5e532FF,
+		       NULL);
 }
